/*******************************************************************************
File Name: CYBLE_gatt.c
Version 2.0

Description:
 This file contains the source code for the GATT API of the BLE Component.

********************************************************************************
Copyright 2014-2015, Cypress Semiconductor Corporation.  All rights reserved.
You may use this file only in accordance with the license, terms, conditions,
disclaimers, and limitations in the end user license agreement accompanying
the software package with which this file was provided.
*******************************************************************************/


#include "BLE_eventHandler.h"


/***************************************
##Global variables
***************************************/

CYBLE_STATE_T cyBle_state;


#if(CYBLE_GATT_ROLE_SERVER)
    
    const CYBLE_GATTS_T cyBle_gatts =
{
    0x0008u,    /* Handle of the GATT service */
    0x000Au,    /* Handle of the Service Changed characteristic */
    0x000Bu,    /* Handle of the Client Characteristic Configuration descriptor */
};
    
    static uint8 cyBle_attValues[0xC6u] = {
    /* Device Name */
    (uint8)'K', (uint8)'e', (uint8)'y', (uint8)'b', (uint8)'o', (uint8)'a', (uint8)'r', (uint8)'d', 

    /* Appearance */
    0xC0u, 0x03u, 

    /* Peripheral Preferred Connection Parameters */
    0x08u, 0x00u, 0x08u, 0x00u, 0x64u, 0x00u, 0xDCu, 0x00u, 

    /* Service Changed */
    0x00u, 0x00u, 0x00u, 0x00u, 

    /* Protocol Mode */
    0x01u, 

    /* Report In */
    0x00u, 0x00u, 0x00u, 0x00u, 0x00u, 0x00u, 0x00u, 0x00u, 

    /* Report Reference */
    0x02u, 0x01u, 

    /* Report Out */
    0x00u, 

    /* Report Reference */
    0x02u, 0x02u, 

    /* Report Map */
    
0x05u, 0x01u, /* USAGE_PAGE         */
0x09u, 0x06u, /* USAGE              */
0xA1u, 0x01u, /* COLLECTION        
*/
0x85u, 0x02u, /* REPORT_ID          */
0x05u, 0x07u, /* USAGE_PAGE         */
0x19u, 0xE0u, /* USAGE_MINIMUM     
*/
0x29u, 0xE7u, /* USAGE_MAXIMUM      */
0x15u, 0x00u, /* LOGICAL_MINIMUM    */
0x25u, 0x01u, /* LOGICAL_MAXIMUM   
*/
0x75u, 0x01u, /* REPORT_SIZE        */
0x95u, 0x08u, /* REPORT_COUNT       */
0x81u, 0x02u, /* INPUT             
*/
0x95u, 0x01u, /* REPORT_COUNT       */
0x75u, 0x08u, /* REPORT_SIZE        */
0x81u, 0x01u, /* INPUT             
*/
0x95u, 0x05u, /* REPORT_COUNT       */
0x75u, 0x01u, /* REPORT_SIZE        */
0x05u, 0x08u, /* USAGE_PAGE        
*/
0x19u, 0x01u, /* USAGE_MINIMUM      */
0x29u, 0x05u, /* USAGE_MAXIMUM      */
0x91u, 0x02u, /* OUTPUT            
*/
0x95u, 0x01u, /* REPORT_COUNT       */
0x75u, 0x03u, /* REPORT_SIZE        */
0x91u, 0x01u, /* OUTPUT            
*/
0x95u, 0x06u, /* REPORT_COUNT       */
0x75u, 0x08u, /* REPORT_SIZE        */
0x15u, 0x00u, /* LOGICAL_MINIMUM   
*/
0x25u, 0x65u, /* LOGICAL_MAXIMUM    */
0x05u, 0x07u, /* USAGE_PAGE         */
0x19u, 0x00u, /* USAGE_MINIMUM     
*/
0x29u, 0x65u, /* USAGE_MAXIMUM      */
0x81u, 0x00u, /* INPUT              */
0xC0u,      /* END_COLLECTION     */

    /* HID Information */
    0x01u, 0x01u, 0x00u, 0x03u, 

    /* HID Control Point */
    0x00u, 

    /* Boot Keyboard Input Report */
    0x00u, 0x00u, 0x00u, 0x00u, 0x00u, 0x00u, 0x00u, 0x00u, 

    /* Manufacturer Name String */
    (uint8)'C', (uint8)'y', (uint8)'p', (uint8)'r', (uint8)'e', (uint8)'s', (uint8)'s', (uint8)' ', (uint8)'S', (uint8)'e',
(uint8)'m', (uint8)'i', (uint8)'c', (uint8)'o', (uint8)'n', (uint8)'d', (uint8)'u', (uint8)'c', (uint8)'t', (uint8)'o',
(uint8)'r', 

    /* Firmware Revision String */
    (uint8)'1', (uint8)'.', (uint8)'0', (uint8)'.', (uint8)'0', (uint8)'.', (uint8)'0', 

    /* PnP ID */
    0x02u, 0xB4u, 0x04u, 0x73u, 0x56u, 0x01u, 0x00u, 

    /* Hardware Revision String */
    (uint8)'1', (uint8)'.', (uint8)'0', 

    /* Serial Number String */
    (uint8)'1', (uint8)'2', (uint8)'3', (uint8)'4', (uint8)'5', (uint8)'6', (uint8)'7', (uint8)'8', (uint8)'9', (uint8)'0',
(uint8)'1', (uint8)'2', 

    /* Software Revision String */
    (uint8)'P', (uint8)'S', (uint8)'o', (uint8)'C', (uint8)' ', (uint8)'C', (uint8)'r', (uint8)'e', (uint8)'a', (uint8)'t',
(uint8)'o', (uint8)'r', 

    /* Model Number String */
    (uint8)'C', (uint8)'Y', (uint8)'5', (uint8)'6', (uint8)'7', (uint8)'2', 

    /* Battery Level */
    0x64u, 

    /* Characteristic Presentation Format */
    0x04u, 0x01u, 0xADu, 0x27u, 0x01u, 0x06u, 0x01u, 

    /* Scan Interval Window */
    0x00u, 0x00u, 0x00u, 0x00u, 

    /* Scan Refresh */
    0x00u, 

    /* Alert Level */
    0x00u, 

    /* Alert Level */
    0x00u, 

    /* Tx Power Level */
    0x00u, 

};

#if defined(__GNUC__) || defined(__ARMCC_VERSION)
const uint8 cyBle_attValuesCCCDFlashMemory[CYBLE_GAP_MAX_BONDED_DEVICE + 1u][CYBLE_GATT_DB_CCCD_COUNT] CYBLE_FLASH_ROW_ALIGNED = {
#elif defined(__ICCARM__)
/* The cyBle_attValuesCCCDFlashMemory[] should be aligned to the size of a Flash row */
#pragma data_alignment=CY_FLASH_SIZEOF_ROW
const uint8 cyBle_attValuesCCCDFlashMemory[CYBLE_GAP_MAX_BONDED_DEVICE + 1u][CYBLE_GATT_DB_CCCD_COUNT] = {
#endif /* defined(__GNUC__) || defined(__ARMCC_VERSION) */
{
    0x00u, 0x00u, 
    0x00u, 0x00u, 
    0x00u, 0x00u, 
    0x00u, 0x00u, 
    0x00u, 0x00u, 
    0x00u, 0x00u, 
    0x00u, 0x00u, 
},
{
    0x00u, 0x00u, 
    0x00u, 0x00u, 
    0x00u, 0x00u, 
    0x00u, 0x00u, 
    0x00u, 0x00u, 
    0x00u, 0x00u, 
    0x00u, 0x00u, 
},
{
    0x00u, 0x00u, 
    0x00u, 0x00u, 
    0x00u, 0x00u, 
    0x00u, 0x00u, 
    0x00u, 0x00u, 
    0x00u, 0x00u, 
    0x00u, 0x00u, 
},
{
    0x00u, 0x00u, 
    0x00u, 0x00u, 
    0x00u, 0x00u, 
    0x00u, 0x00u, 
    0x00u, 0x00u, 
    0x00u, 0x00u, 
    0x00u, 0x00u, 
},
{
    0x00u, 0x00u, 
    0x00u, 0x00u, 
    0x00u, 0x00u, 
    0x00u, 0x00u, 
    0x00u, 0x00u, 
    0x00u, 0x00u, 
    0x00u, 0x00u, 
},
};
uint8 cyBle_attValuesCCCD[CYBLE_GATT_DB_CCCD_COUNT];

CYBLE_GATTS_ATT_GEN_VAL_LEN_T cyBle_attValuesLen[CYBLE_GATT_DB_ATT_VAL_COUNT] = {
    { 0x0008u, (void *)&cyBle_attValues[0] }, /* Device Name */
    { 0x0002u, (void *)&cyBle_attValues[8] }, /* Appearance */
    { 0x0008u, (void *)&cyBle_attValues[10] }, /* Peripheral Preferred Connection Parameters */
    { 0x0004u, (void *)&cyBle_attValues[18] }, /* Service Changed */
    { 0x0002u, (void *)&cyBle_attValuesCCCD[0] }, /* Client Characteristic Configuration */
    { 0x0001u, (void *)&cyBle_attValues[22] }, /* Protocol Mode */
    { 0x0008u, (void *)&cyBle_attValues[23] }, /* Report In */
    { 0x0002u, (void *)&cyBle_attValuesCCCD[2] }, /* Client Characteristic Configuration */
    { 0x0002u, (void *)&cyBle_attValues[31] }, /* Report Reference */
    { 0x0001u, (void *)&cyBle_attValues[33] }, /* Report Out */
    { 0x0002u, (void *)&cyBle_attValuesCCCD[4] }, /* Client Characteristic Configuration */
    { 0x0002u, (void *)&cyBle_attValues[34] }, /* Report Reference */
    { 0x0041u, (void *)&cyBle_attValues[36] }, /* Report Map */
    { 0x0004u, (void *)&cyBle_attValues[101] }, /* HID Information */
    { 0x0001u, (void *)&cyBle_attValues[105] }, /* HID Control Point */
    { 0x0008u, (void *)&cyBle_attValues[106] }, /* Boot Keyboard Input Report */
    { 0x0002u, (void *)&cyBle_attValuesCCCD[6] }, /* Client Characteristic Configuration */
    { 0x0015u, (void *)&cyBle_attValues[114] }, /* Manufacturer Name String */
    { 0x0007u, (void *)&cyBle_attValues[135] }, /* Firmware Revision String */
    { 0x0007u, (void *)&cyBle_attValues[142] }, /* PnP ID */
    { 0x0003u, (void *)&cyBle_attValues[149] }, /* Hardware Revision String */
    { 0x000Cu, (void *)&cyBle_attValues[152] }, /* Serial Number String */
    { 0x000Cu, (void *)&cyBle_attValues[164] }, /* Software Revision String */
    { 0x0006u, (void *)&cyBle_attValues[176] }, /* Model Number String */
    { 0x0001u, (void *)&cyBle_attValues[182] }, /* Battery Level */
    { 0x0007u, (void *)&cyBle_attValues[183] }, /* Characteristic Presentation Format */
    { 0x0002u, (void *)&cyBle_attValuesCCCD[8] }, /* Client Characteristic Configuration */
    { 0x0004u, (void *)&cyBle_attValues[190] }, /* Scan Interval Window */
    { 0x0001u, (void *)&cyBle_attValues[194] }, /* Scan Refresh */
    { 0x0002u, (void *)&cyBle_attValuesCCCD[10] }, /* Client Characteristic Configuration */
    { 0x0001u, (void *)&cyBle_attValues[195] }, /* Alert Level */
    { 0x0001u, (void *)&cyBle_attValues[196] }, /* Alert Level */
    { 0x0001u, (void *)&cyBle_attValues[197] }, /* Tx Power Level */
    { 0x0002u, (void *)&cyBle_attValuesCCCD[12] }, /* Client Characteristic Configuration */
};

const CYBLE_GATTS_DB_T cyBle_gattDB[0x43u] = {
    { 0x0001u, 0x2800u /* Primary service                     */, 0x00000001u /*        */, 0x0007u, {{0x1800u, NULL}}                           },
    { 0x0002u, 0x2803u /* Characteristic                      */, 0x00000201u /* rd     */, 0x0003u, {{0x2A00u, NULL}}                           },
    { 0x0003u, 0x2A00u /* Device Name                         */, 0x00000201u /* rd     */, 0x0003u, {{0x0008u, (void *)&cyBle_attValuesLen[0]}} },
    { 0x0004u, 0x2803u /* Characteristic                      */, 0x00000201u /* rd     */, 0x0005u, {{0x2A01u, NULL}}                           },
    { 0x0005u, 0x2A01u /* Appearance                          */, 0x00000201u /* rd     */, 0x0005u, {{0x0002u, (void *)&cyBle_attValuesLen[1]}} },
    { 0x0006u, 0x2803u /* Characteristic                      */, 0x00000201u /* rd     */, 0x0007u, {{0x2A04u, NULL}}                           },
    { 0x0007u, 0x2A04u /* Peripheral Preferred Connection Par */, 0x00000201u /* rd     */, 0x0007u, {{0x0008u, (void *)&cyBle_attValuesLen[2]}} },
    { 0x0008u, 0x2800u /* Primary service                     */, 0x00000001u /*        */, 0x000Bu, {{0x1801u, NULL}}                           },
    { 0x0009u, 0x2803u /* Characteristic                      */, 0x00002201u /* rd,ind */, 0x000Bu, {{0x2A05u, NULL}}                           },
    { 0x000Au, 0x2A05u /* Service Changed                     */, 0x00002209u /* rd,ind */, 0x000Bu, {{0x0004u, (void *)&cyBle_attValuesLen[3]}} },
    { 0x000Bu, 0x2902u /* Client Characteristic Configuration */, 0x00000A0Eu /* rd,wr  */, 0x000Bu, {{0x0002u, (void *)&cyBle_attValuesLen[4]}} },
    { 0x000Cu, 0x2800u /* Primary service                     */, 0x00000001u /*        */, 0x001Fu, {{0x1812u, NULL}}                           },
    { 0x000Du, 0x2803u /* Characteristic                      */, 0x00000601u /* rd,wwr */, 0x000Eu, {{0x2A4Eu, NULL}}                           },
    { 0x000Eu, 0x2A4Eu /* Protocol Mode                       */, 0x0000060Fu /* rd,wwr */, 0x000Eu, {{0x0001u, (void *)&cyBle_attValuesLen[5]}} },
    { 0x000Fu, 0x2803u /* Characteristic                      */, 0x00001201u /* rd,ntf */, 0x0012u, {{0x2A4Du, NULL}}                           },
    { 0x0010u, 0x2A4Du /* Report In                           */, 0x00001209u /* rd,ntf */, 0x0012u, {{0x0008u, (void *)&cyBle_attValuesLen[6]}} },
    { 0x0011u, 0x2902u /* Client Characteristic Configuration */, 0x00000A0Eu /* rd,wr  */, 0x0011u, {{0x0002u, (void *)&cyBle_attValuesLen[7]}} },
    { 0x0012u, 0x2908u /* Report Reference                    */, 0x00000201u /* rd     */, 0x0012u, {{0x0002u, (void *)&cyBle_attValuesLen[8]}} },
    { 0x0013u, 0x2803u /* Characteristic                      */, 0x00001201u /* rd,ntf */, 0x0016u, {{0x2A4Du, NULL}}                           },
    { 0x0014u, 0x2A4Du /* Report Out                          */, 0x00001209u /* rd,ntf */, 0x0016u, {{0x0001u, (void *)&cyBle_attValuesLen[9]}} },
    { 0x0015u, 0x2902u /* Client Characteristic Configuration */, 0x00000A0Eu /* rd,wr  */, 0x0015u, {{0x0002u, (void *)&cyBle_attValuesLen[10]}} },
    { 0x0016u, 0x2908u /* Report Reference                    */, 0x00000201u /* rd     */, 0x0016u, {{0x0002u, (void *)&cyBle_attValuesLen[11]}} },
    { 0x0017u, 0x2803u /* Characteristic                      */, 0x00000201u /* rd     */, 0x0018u, {{0x2A4Bu, NULL}}                           },
    { 0x0018u, 0x2A4Bu /* Report Map                          */, 0x00000209u /* rd     */, 0x0018u, {{0x0041u, (void *)&cyBle_attValuesLen[12]}} },
    { 0x0019u, 0x2803u /* Characteristic                      */, 0x00000201u /* rd     */, 0x001Au, {{0x2A4Au, NULL}}                           },
    { 0x001Au, 0x2A4Au /* HID Information                     */, 0x00000209u /* rd     */, 0x001Au, {{0x0004u, (void *)&cyBle_attValuesLen[13]}} },
    { 0x001Bu, 0x2803u /* Characteristic                      */, 0x00000401u /* wwr    */, 0x001Cu, {{0x2A4Cu, NULL}}                           },
    { 0x001Cu, 0x2A4Cu /* HID Control Point                   */, 0x0000040Au /* wwr    */, 0x001Cu, {{0x0001u, (void *)&cyBle_attValuesLen[14]}} },
    { 0x001Du, 0x2803u /* Characteristic                      */, 0x00001201u /* rd,ntf */, 0x001Fu, {{0x2A22u, NULL}}                           },
    { 0x001Eu, 0x2A22u /* Boot Keyboard Input Report          */, 0x00001209u /* rd,ntf */, 0x001Fu, {{0x0008u, (void *)&cyBle_attValuesLen[15]}} },
    { 0x001Fu, 0x2902u /* Client Characteristic Configuration */, 0x00000A0Eu /* rd,wr  */, 0x001Fu, {{0x0002u, (void *)&cyBle_attValuesLen[16]}} },
    { 0x0020u, 0x2800u /* Primary service                     */, 0x00000001u /*        */, 0x002Eu, {{0x180Au, NULL}}                           },
    { 0x0021u, 0x2803u /* Characteristic                      */, 0x00000201u /* rd     */, 0x0022u, {{0x2A29u, NULL}}                           },
    { 0x0022u, 0x2A29u /* Manufacturer Name String            */, 0x00000209u /* rd     */, 0x0022u, {{0x0015u, (void *)&cyBle_attValuesLen[17]}} },
    { 0x0023u, 0x2803u /* Characteristic                      */, 0x00000201u /* rd     */, 0x0024u, {{0x2A26u, NULL}}                           },
    { 0x0024u, 0x2A26u /* Firmware Revision String            */, 0x00000209u /* rd     */, 0x0024u, {{0x0007u, (void *)&cyBle_attValuesLen[18]}} },
    { 0x0025u, 0x2803u /* Characteristic                      */, 0x00000201u /* rd     */, 0x0026u, {{0x2A50u, NULL}}                           },
    { 0x0026u, 0x2A50u /* PnP ID                              */, 0x00000209u /* rd     */, 0x0026u, {{0x0007u, (void *)&cyBle_attValuesLen[19]}} },
    { 0x0027u, 0x2803u /* Characteristic                      */, 0x00000201u /* rd     */, 0x0028u, {{0x2A27u, NULL}}                           },
    { 0x0028u, 0x2A27u /* Hardware Revision String            */, 0x00000209u /* rd     */, 0x0028u, {{0x0003u, (void *)&cyBle_attValuesLen[20]}} },
    { 0x0029u, 0x2803u /* Characteristic                      */, 0x00000201u /* rd     */, 0x002Au, {{0x2A25u, NULL}}                           },
    { 0x002Au, 0x2A25u /* Serial Number String                */, 0x00000209u /* rd     */, 0x002Au, {{0x000Cu, (void *)&cyBle_attValuesLen[21]}} },
    { 0x002Bu, 0x2803u /* Characteristic                      */, 0x00000201u /* rd     */, 0x002Cu, {{0x2A28u, NULL}}                           },
    { 0x002Cu, 0x2A28u /* Software Revision String            */, 0x00000209u /* rd     */, 0x002Cu, {{0x000Cu, (void *)&cyBle_attValuesLen[22]}} },
    { 0x002Du, 0x2803u /* Characteristic                      */, 0x00000201u /* rd     */, 0x002Eu, {{0x2A24u, NULL}}                           },
    { 0x002Eu, 0x2A24u /* Model Number String                 */, 0x00000209u /* rd     */, 0x002Eu, {{0x0006u, (void *)&cyBle_attValuesLen[23]}} },
    { 0x002Fu, 0x2800u /* Primary service                     */, 0x00000001u /*        */, 0x0033u, {{0x180Fu, NULL}}                           },
    { 0x0030u, 0x2803u /* Characteristic                      */, 0x00001201u /* rd,ntf */, 0x0033u, {{0x2A19u, NULL}}                           },
    { 0x0031u, 0x2A19u /* Battery Level                       */, 0x00001209u /* rd,ntf */, 0x0033u, {{0x0001u, (void *)&cyBle_attValuesLen[24]}} },
    { 0x0032u, 0x2904u /* Characteristic Presentation Format  */, 0x00000201u /* rd     */, 0x0032u, {{0x0007u, (void *)&cyBle_attValuesLen[25]}} },
    { 0x0033u, 0x2902u /* Client Characteristic Configuration */, 0x00000A0Eu /* rd,wr  */, 0x0033u, {{0x0002u, (void *)&cyBle_attValuesLen[26]}} },
    { 0x0034u, 0x2800u /* Primary service                     */, 0x00000001u /*        */, 0x0039u, {{0x1813u, NULL}}                           },
    { 0x0035u, 0x2803u /* Characteristic                      */, 0x00000401u /* wwr    */, 0x0036u, {{0x2A4Fu, NULL}}                           },
    { 0x0036u, 0x2A4Fu /* Scan Interval Window                */, 0x0000040Au /* wwr    */, 0x0036u, {{0x0004u, (void *)&cyBle_attValuesLen[27]}} },
    { 0x0037u, 0x2803u /* Characteristic                      */, 0x00001001u /* ntf    */, 0x0039u, {{0x2A31u, NULL}}                           },
    { 0x0038u, 0x2A31u /* Scan Refresh                        */, 0x00001000u /* ntf    */, 0x0039u, {{0x0001u, (void *)&cyBle_attValuesLen[28]}} },
    { 0x0039u, 0x2902u /* Client Characteristic Configuration */, 0x00000A0Eu /* rd,wr  */, 0x0039u, {{0x0002u, (void *)&cyBle_attValuesLen[29]}} },
    { 0x003Au, 0x2800u /* Primary service                     */, 0x00000001u /*        */, 0x003Cu, {{0x1803u, NULL}}                           },
    { 0x003Bu, 0x2803u /* Characteristic                      */, 0x00000A01u /* rd,wr  */, 0x003Cu, {{0x2A06u, NULL}}                           },
    { 0x003Cu, 0x2A06u /* Alert Level                         */, 0x00000A0Fu /* rd,wr  */, 0x003Cu, {{0x0001u, (void *)&cyBle_attValuesLen[30]}} },
    { 0x003Du, 0x2800u /* Primary service                     */, 0x00000001u /*        */, 0x003Fu, {{0x1802u, NULL}}                           },
    { 0x003Eu, 0x2803u /* Characteristic                      */, 0x00000401u /* wwr    */, 0x003Fu, {{0x2A06u, NULL}}                           },
    { 0x003Fu, 0x2A06u /* Alert Level                         */, 0x0000040Au /* wwr    */, 0x003Fu, {{0x0001u, (void *)&cyBle_attValuesLen[31]}} },
    { 0x0040u, 0x2800u /* Primary service                     */, 0x00000001u /*        */, 0x0043u, {{0x1804u, NULL}}                           },
    { 0x0041u, 0x2803u /* Characteristic                      */, 0x00000201u /* rd     */, 0x0043u, {{0x2A07u, NULL}}                           },
    { 0x0042u, 0x2A07u /* Tx Power Level                      */, 0x00000209u /* rd     */, 0x0043u, {{0x0001u, (void *)&cyBle_attValuesLen[32]}} },
    { 0x0043u, 0x2902u /* Client Characteristic Configuration */, 0x00000A0Eu /* rd,wr  */, 0x0043u, {{0x0002u, (void *)&cyBle_attValuesLen[33]}} },
};


#endif /* (CYBLE_GATT_ROLE_SERVER) */

#if(CYBLE_GATT_ROLE_CLIENT)
    
CYBLE_CLIENT_STATE_T cyBle_clientState;
CYBLE_GATTC_T cyBle_gattc;
    
#endif /* (CYBLE_GATT_ROLE_CLIENT) */


#if(CYBLE_GATT_ROLE_SERVER)

/****************************************************************************** 
##Function Name: CyBle_GattsReInitGattDb
*******************************************************************************

Summary:
 Reinitializes the GATT database.

Parameters:
 None

Return:
 CYBLE_API_RESULT_T: An API result states if the API succeeded or failed with
 error codes:
  * CYBLE_ERROR_OK: GATT database was reinitialized successfully
  * CYBLE_ERROR_INVALID_STATE: If the function is called in any state except
                                CYBLE_STATE_DISCONNECTED.
  * Any of the CyBle_GattsDbRegister() stack API function return values.

******************************************************************************/
CYBLE_API_RESULT_T CyBle_GattsReInitGattDb(void)
{
    CYBLE_API_RESULT_T apiResult;
    
    if(CYBLE_STATE_DISCONNECTED == CyBle_GetState())
    {
        apiResult = CyBle_GattsDbRegister(cyBle_gattDB, CYBLE_GATT_DB_INDEX_COUNT, CYBLE_GATT_DB_MAX_VALUE_LEN);
    }
    else
    {
        apiResult = CYBLE_ERROR_INVALID_STATE;
    }
    
    return(apiResult);
}


/****************************************************************************** 
##Function Name: CyBle_GattsWriteEventHandler
*******************************************************************************

Summary:
 Handles the Write Request Event for GATT service.

Parameters:
 *eventParam: The pointer to the data structure specified by the event.

Return:
 * CYBLE_GATT_ERR_CODE_T: An API result returns one of the following status 
    values
 * CYBLE_GATT_ERR_NONE - Write is successful.

******************************************************************************/
CYBLE_GATT_ERR_CODE_T CyBle_GattsWriteEventHandler(CYBLE_GATTS_WRITE_REQ_PARAM_T *eventParam)
{
    CYBLE_GATT_ERR_CODE_T gattErr = CYBLE_GATT_ERR_NONE;
    
    /* Client Characteristic Configuration descriptor write request */
    if(eventParam->handleValPair.attrHandle == cyBle_gatts.cccdHandle)
    {
        /* Store value to database */
        gattErr = CyBle_GattsWriteAttributeValue(&eventParam->handleValPair, 0u, 
                        &eventParam->connHandle, CYBLE_GATT_DB_PEER_INITIATED);
        
        if(CYBLE_GATT_ERR_NONE == gattErr)
        {
            if(CYBLE_IS_INDICATION_ENABLED_IN_PTR(eventParam->handleValPair.value.val))
            {
                CyBle_ApplCallback((uint32)CYBLE_EVT_GATTS_INDICATION_ENABLED, eventParam);
            }
            else
            {
                CyBle_ApplCallback((uint32)CYBLE_EVT_GATTS_INDICATION_DISABLED, eventParam);
            }
        }
        cyBle_eventHandlerFlag &= (uint8)~CYBLE_CALLBACK;
    }
    return (gattErr);
}


#endif /* (CYBLE_GATT_ROLE_SERVER) */

#if(CYBLE_GATT_ROLE_CLIENT)


/****************************************************************************** 
##Function Name: CyBle_GattcStartDiscovery
*******************************************************************************

Summary:
 Starts the automatic server discovery process. Two events may be generated 
 after calling this function - CYBLE_EVT_GATTC_DISCOVERY_COMPLETE or 
 CYBLE_EVT_GATTC_ERROR_RSP. The CYBLE_EVT_GATTC_DISCOVERY_COMPLETE event is 
 generated when the remote device was successfully discovered. The
 CYBLE_EVT_GATTC_ERROR_RSP is generated if the device discovery is failed.

Parameters:
 connHandle: The handle which consists of the device ID and ATT connection ID.

Return:
  CYBLE_API_RESULT_T : Return value indicates if the function succeeded or
                       failed. Following are the possible error codes.
  CYBLE_ERROR_OK - On successful operation
  CYBLE_ERROR_INVALID_PARAMETER - 'connHandle' value does not represent any
                                   existing entry.
                                                 in the Stack
  CYBLE_ERROR_INVALID_OPERATION - The operation is not permitted.
  CYBLE_ERROR_MEMORY_ALLOCATION_FAILED - Memory allocation failed.

******************************************************************************/
CYBLE_API_RESULT_T CyBle_GattcStartDiscovery(CYBLE_CONN_HANDLE_T connHandle)
{
    uint8 j;
    CYBLE_API_RESULT_T apiResult;
    
    if(CYBLE_STATE_CONNECTED != CyBle_GetState())
    {
        apiResult = CYBLE_ERROR_INVALID_STATE;
    }
    else
    {
        CyBle_ServiceInit();
        
        cyBle_connHandle = connHandle;

        /* Clean old discovery information */
        for(j = 0u; j < (uint8) CYBLE_SRVI_COUNT; j++)
        {
            (void)memset(&cyBle_serverInfo[j].range, 0, sizeof(cyBle_serverInfo[0].range));
        }

        apiResult = CyBle_GattcDiscoverAllPrimaryServices(connHandle);

        if(CYBLE_ERROR_OK == apiResult)
        {
            CyBle_SetClientState(CYBLE_CLIENT_STATE_SRVC_DISCOVERING);
            cyBle_eventHandlerFlag |= CYBLE_AUTO_DISCOVERY;
        }
    }
    
    return (apiResult);
}


/******************************************************************************
##Function Name: CyBle_GattcDiscoverCharacteristicsEventHandler
*******************************************************************************

Summary:
 This function is called on receiving a "CYBLE_EVT_GATTC_READ_BY_TYPE_RSP"
 event. Based on the service UUID, an appropriate data structure is populated
 using the data received as part of the callback.

Parameters:
 *discCharInfo: The pointer to a characteristic information structure.

Return:
 None

******************************************************************************/
void CyBle_GattcDiscoverCharacteristicsEventHandler(CYBLE_DISC_CHAR_INFO_T *discCharInfo)
{
    if(discCharInfo->uuid.uuid16 == CYBLE_UUID_CHAR_SERVICE_CHANGED)
    {
        CyBle_CheckStoreCharHandle(cyBle_gattc.serviceChanged);
    }
}


/******************************************************************************
##Function Name: CyBle_GattcDiscoverCharDescriptorsEventHandler
*******************************************************************************

Summary:
 This function is called on receiving a "CYBLE_EVT_GATTC_FIND_INFO_RSP" event.
 Based on the descriptor UUID, an appropriate data structure is populated 
 using the data received as part of the callback.

Parameters:
 *discDescrInfo: The pointer to a descriptor information structure.
 discoveryService: The index of the service instance

Return:
 None

******************************************************************************/
void CyBle_GattcDiscoverCharDescriptorsEventHandler(CYBLE_DISC_DESCR_INFO_T *discDescrInfo)
{
    if(discDescrInfo->uuid.uuid16 == CYBLE_UUID_CHAR_CLIENT_CONFIG)
    {
        CyBle_CheckStoreCharDescrHandle(cyBle_gattc.cccdHandle);
    }
}


/******************************************************************************
##Function Name: CyBle_GattcIndicationEventHandler
*******************************************************************************

Summary:
 Handles the Indication Event.

Parameters:
 *eventParam: The pointer to the data structure specified by the event.

Return:
 None.

******************************************************************************/
void CyBle_GattcIndicationEventHandler(CYBLE_GATTC_HANDLE_VALUE_IND_PARAM_T *eventParam)
{
    if(cyBle_gattc.serviceChanged.valueHandle == eventParam->handleValPair.attrHandle)
    {
        CyBle_ApplCallback((uint32)CYBLE_EVT_GATTC_INDICATION, eventParam);
        cyBle_eventHandlerFlag &= (uint8)~CYBLE_CALLBACK;
    }
}


#endif /* (CYBLE_GATT_ROLE_CLIENT) */


/* [] END OF FILE */
