/*******************************************************************************
* File Name: SBC_BOOT.h
* Version 3.0
*
* Description:
*  This file provides constants and parameter values of the bootloader
*  communication APIs for the SCB Component.
*
* Note:
*
********************************************************************************
* Copyright 2014-2015, Cypress Semiconductor Corporation. All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_SCB_BOOT_SBC_H)
#define CY_SCB_BOOT_SBC_H

#include "SBC_PVT.h"

#if (SBC_SCB_MODE_I2C_INC)
    #include "SBC_I2C.h"
#endif /* (SBC_SCB_MODE_I2C_INC) */

#if (SBC_SCB_MODE_EZI2C_INC)
    #include "SBC_EZI2C.h"
#endif /* (SBC_SCB_MODE_EZI2C_INC) */

#if (SBC_SCB_MODE_SPI_INC || SBC_SCB_MODE_UART_INC)
    #include "SBC_SPI_UART.h"
#endif /* (SBC_SCB_MODE_SPI_INC || SBC_SCB_MODE_UART_INC) */


/***************************************
*  Conditional Compilation Parameters
****************************************/

/* Bootloader communication interface enable */
#define SBC_BTLDR_COMM_ENABLED ((CYDEV_BOOTLOADER_IO_COMP == CyBtldr_SBC) || \
                                             (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_Custom_Interface))

/* Enable I2C bootloader communication */
#if (SBC_SCB_MODE_I2C_INC)
    #define SBC_I2C_BTLDR_COMM_ENABLED     (SBC_BTLDR_COMM_ENABLED && \
                                                            (SBC_SCB_MODE_UNCONFIG_CONST_CFG || \
                                                             SBC_I2C_SLAVE_CONST))
#else
     #define SBC_I2C_BTLDR_COMM_ENABLED    (0u)
#endif /* (SBC_SCB_MODE_I2C_INC) */

/* EZI2C does not support bootloader communication. Provide empty APIs */
#if (SBC_SCB_MODE_EZI2C_INC)
    #define SBC_EZI2C_BTLDR_COMM_ENABLED   (SBC_BTLDR_COMM_ENABLED && \
                                                         SBC_SCB_MODE_UNCONFIG_CONST_CFG)
#else
    #define SBC_EZI2C_BTLDR_COMM_ENABLED   (0u)
#endif /* (SBC_EZI2C_BTLDR_COMM_ENABLED) */

/* Enable SPI bootloader communication */
#if (SBC_SCB_MODE_SPI_INC)
    #define SBC_SPI_BTLDR_COMM_ENABLED     (SBC_BTLDR_COMM_ENABLED && \
                                                            (SBC_SCB_MODE_UNCONFIG_CONST_CFG || \
                                                             SBC_SPI_SLAVE_CONST))
#else
        #define SBC_SPI_BTLDR_COMM_ENABLED (0u)
#endif /* (SBC_SPI_BTLDR_COMM_ENABLED) */

/* Enable UART bootloader communication */
#if (SBC_SCB_MODE_UART_INC)
       #define SBC_UART_BTLDR_COMM_ENABLED    (SBC_BTLDR_COMM_ENABLED && \
                                                            (SBC_SCB_MODE_UNCONFIG_CONST_CFG || \
                                                             (SBC_UART_RX_DIRECTION && \
                                                              SBC_UART_TX_DIRECTION)))
#else
     #define SBC_UART_BTLDR_COMM_ENABLED   (0u)
#endif /* (SBC_UART_BTLDR_COMM_ENABLED) */

/* Enable bootloader communication */
#define SBC_BTLDR_COMM_MODE_ENABLED    (SBC_I2C_BTLDR_COMM_ENABLED   || \
                                                     SBC_SPI_BTLDR_COMM_ENABLED   || \
                                                     SBC_EZI2C_BTLDR_COMM_ENABLED || \
                                                     SBC_UART_BTLDR_COMM_ENABLED)


/***************************************
*        Function Prototypes
***************************************/

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (SBC_I2C_BTLDR_COMM_ENABLED)
    /* I2C Bootloader physical layer functions */
    void SBC_I2CCyBtldrCommStart(void);
    void SBC_I2CCyBtldrCommStop (void);
    void SBC_I2CCyBtldrCommReset(void);
    cystatus SBC_I2CCyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    cystatus SBC_I2CCyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);

    /* Map I2C specific bootloader communication APIs to SCB specific APIs */
    #if (SBC_SCB_MODE_I2C_CONST_CFG)
        #define SBC_CyBtldrCommStart   SBC_I2CCyBtldrCommStart
        #define SBC_CyBtldrCommStop    SBC_I2CCyBtldrCommStop
        #define SBC_CyBtldrCommReset   SBC_I2CCyBtldrCommReset
        #define SBC_CyBtldrCommRead    SBC_I2CCyBtldrCommRead
        #define SBC_CyBtldrCommWrite   SBC_I2CCyBtldrCommWrite
    #endif /* (SBC_SCB_MODE_I2C_CONST_CFG) */

#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (SBC_I2C_BTLDR_COMM_ENABLED) */


#if defined(CYDEV_BOOTLOADER_IO_COMP) && (SBC_EZI2C_BTLDR_COMM_ENABLED)
    /* Bootloader physical layer functions */
    void SBC_EzI2CCyBtldrCommStart(void);
    void SBC_EzI2CCyBtldrCommStop (void);
    void SBC_EzI2CCyBtldrCommReset(void);
    cystatus SBC_EzI2CCyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    cystatus SBC_EzI2CCyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);

    /* Map EZI2C specific bootloader communication APIs to SCB specific APIs */
    #if (SBC_SCB_MODE_EZI2C_CONST_CFG)
        #define SBC_CyBtldrCommStart   SBC_EzI2CCyBtldrCommStart
        #define SBC_CyBtldrCommStop    SBC_EzI2CCyBtldrCommStop
        #define SBC_CyBtldrCommReset   SBC_EzI2CCyBtldrCommReset
        #define SBC_CyBtldrCommRead    SBC_EzI2CCyBtldrCommRead
        #define SBC_CyBtldrCommWrite   SBC_EzI2CCyBtldrCommWrite
    #endif /* (SBC_SCB_MODE_EZI2C_CONST_CFG) */

#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (SBC_EZI2C_BTLDR_COMM_ENABLED) */

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (SBC_SPI_BTLDR_COMM_ENABLED)
    /* SPI Bootloader physical layer functions */
    void SBC_SpiCyBtldrCommStart(void);
    void SBC_SpiCyBtldrCommStop (void);
    void SBC_SpiCyBtldrCommReset(void);
    cystatus SBC_SpiCyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    cystatus SBC_SpiCyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);

    /* Map SPI specific bootloader communication APIs to SCB specific APIs */
    #if (SBC_SCB_MODE_SPI_CONST_CFG)
        #define SBC_CyBtldrCommStart   SBC_SpiCyBtldrCommStart
        #define SBC_CyBtldrCommStop    SBC_SpiCyBtldrCommStop
        #define SBC_CyBtldrCommReset   SBC_SpiCyBtldrCommReset
        #define SBC_CyBtldrCommRead    SBC_SpiCyBtldrCommRead
        #define SBC_CyBtldrCommWrite   SBC_SpiCyBtldrCommWrite
    #endif /* (SBC_SCB_MODE_SPI_CONST_CFG) */

#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (SBC_SPI_BTLDR_COMM_ENABLED) */

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (SBC_UART_BTLDR_COMM_ENABLED)
    /* UART Bootloader physical layer functions */
    void SBC_UartCyBtldrCommStart(void);
    void SBC_UartCyBtldrCommStop (void);
    void SBC_UartCyBtldrCommReset(void);
    cystatus SBC_UartCyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    cystatus SBC_UartCyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);

    /* Map UART specific bootloader communication APIs to SCB specific APIs */
    #if (SBC_SCB_MODE_UART_CONST_CFG)
        #define SBC_CyBtldrCommStart   SBC_UartCyBtldrCommStart
        #define SBC_CyBtldrCommStop    SBC_UartCyBtldrCommStop
        #define SBC_CyBtldrCommReset   SBC_UartCyBtldrCommReset
        #define SBC_CyBtldrCommRead    SBC_UartCyBtldrCommRead
        #define SBC_CyBtldrCommWrite   SBC_UartCyBtldrCommWrite
    #endif /* (SBC_SCB_MODE_UART_CONST_CFG) */

#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (SBC_UART_BTLDR_COMM_ENABLED) */

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (SBC_BTLDR_COMM_ENABLED)
    #if (SBC_SCB_MODE_UNCONFIG_CONST_CFG)
        /* Bootloader physical layer functions */
        void SBC_CyBtldrCommStart(void);
        void SBC_CyBtldrCommStop (void);
        void SBC_CyBtldrCommReset(void);
        cystatus SBC_CyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
        cystatus SBC_CyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    #endif /* (SBC_SCB_MODE_UNCONFIG_CONST_CFG) */

    /* Map SCB specific bootloader communication APIs to common APIs */
    #if (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_SBC)
        #define CyBtldrCommStart    SBC_CyBtldrCommStart
        #define CyBtldrCommStop     SBC_CyBtldrCommStop
        #define CyBtldrCommReset    SBC_CyBtldrCommReset
        #define CyBtldrCommWrite    SBC_CyBtldrCommWrite
        #define CyBtldrCommRead     SBC_CyBtldrCommRead
    #endif /* (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_SBC) */

#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (SBC_BTLDR_COMM_ENABLED) */


/***************************************
*           API Constants
***************************************/

/* Timeout unit in milliseconds */
#define SBC_WAIT_1_MS  (1u)

/* Return number of bytes to copy into bootloader buffer */
#define SBC_BYTES_TO_COPY(actBufSize, bufSize) \
                            ( ((uint32)(actBufSize) < (uint32)(bufSize)) ? \
                                ((uint32) (actBufSize)) : ((uint32) (bufSize)) )

/* Size of Read/Write buffers for I2C bootloader  */
#define SBC_I2C_BTLDR_SIZEOF_READ_BUFFER   (64u)
#define SBC_I2C_BTLDR_SIZEOF_WRITE_BUFFER  (64u)

/* Byte to byte time interval: calculated basing on current component
* data rate configuration, can be defined in project if required.
*/
#ifndef SBC_SPI_BYTE_TO_BYTE
    #define SBC_SPI_BYTE_TO_BYTE   (160u)
#endif

/* Byte to byte time interval: calculated basing on current component
* baud rate configuration, can be defined in the project if required.
*/
#ifndef SBC_UART_BYTE_TO_BYTE
    #define SBC_UART_BYTE_TO_BYTE  (2500u)
#endif /* SBC_UART_BYTE_TO_BYTE */

#endif /* (CY_SCB_BOOT_SBC_H) */


/* [] END OF FILE */
