/*******************************************************************************
* File Name: SBC_EZI2C.h
* Version 3.0
*
* Description:
*  This file provides constants and parameter values for the SCB Component in
*  the EZI2C mode.
*
* Note:
*
********************************************************************************
* Copyright 2013-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_SCB_EZI2C_SBC_H)
#define CY_SCB_EZI2C_SBC_H

#include "SBC.h"


/***************************************
*   Initial Parameter Constants
****************************************/

#define SBC_EZI2C_CLOCK_STRETCHING         (1u)
#define SBC_EZI2C_MEDIAN_FILTER_ENABLE     (1u)
#define SBC_EZI2C_NUMBER_OF_ADDRESSES      (0u)
#define SBC_EZI2C_PRIMARY_SLAVE_ADDRESS    (8u)
#define SBC_EZI2C_SECONDARY_SLAVE_ADDRESS  (9u)
#define SBC_EZI2C_SUB_ADDRESS_SIZE         (1u)
#define SBC_EZI2C_WAKE_ENABLE              (0u)
#define SBC_EZI2C_DATA_RATE                (100u)
#define SBC_EZI2C_SLAVE_ADDRESS_MASK       (254u)
#define SBC_EZI2C_BYTE_MODE_ENABLE         (0u)


/***************************************
*  Conditional Compilation Parameters
****************************************/

#if(SBC_SCB_MODE_UNCONFIG_CONST_CFG)

    #define SBC_SUB_ADDRESS_SIZE16             (0u != SBC_subAddrSize)
    #define SBC_SECONDARY_ADDRESS_ENABLE       (0u != SBC_numberOfAddr)

    #define SBC_EZI2C_EC_AM_ENABLE         (0u != (SBC_CTRL_REG & \
                                                                SBC_CTRL_EC_AM_MODE))
    #define SBC_EZI2C_SCL_STRETCH_ENABLE   (0u != (SBC_GetSlaveInterruptMode() & \
                                                                SBC_INTR_SLAVE_I2C_ADDR_MATCH))
    #define SBC_EZI2C_SCL_STRETCH_DISABLE       (!SBC_EZI2C_SCL_STRETCH_ENABLE)

    #define SBC_SECONDARY_ADDRESS_ENABLE_CONST  (1u)
    #define SBC_SUB_ADDRESS_SIZE16_CONST        (1u)
    #define SBC_EZI2C_SCL_STRETCH_ENABLE_CONST  (1u)
    #define SBC_EZI2C_SCL_STRETCH_DISABLE_CONST (1u)
    #define SBC_EZI2C_WAKE_ENABLE_CONST         (1u)

    #if (SBC_CY_SCBIP_V0 || SBC_CY_SCBIP_V1)
        #define SBC_EZI2C_FIFO_SIZE    (SBC_FIFO_SIZE)
    #else
        #define SBC_EZI2C_FIFO_SIZE    (SBC_GET_FIFO_SIZE(SBC_CTRL_REG & \
                                                                                    SBC_CTRL_BYTE_MODE))
    #endif /* (SBC_CY_SCBIP_V0 || SBC_CY_SCBIP_V1) */

#else

    #define SBC_SUB_ADDRESS_SIZE16         (0u != SBC_EZI2C_SUB_ADDRESS_SIZE)
    #define SBC_SUB_ADDRESS_SIZE16_CONST   (SBC_SUB_ADDRESS_SIZE16)

    #define SBC_SECONDARY_ADDRESS_ENABLE        (0u != SBC_EZI2C_NUMBER_OF_ADDRESSES)
    #define SBC_SECONDARY_ADDRESS_ENABLE_CONST  (SBC_SECONDARY_ADDRESS_ENABLE)

    #define SBC_EZI2C_SCL_STRETCH_ENABLE        (0u != SBC_EZI2C_CLOCK_STRETCHING)
    #define SBC_EZI2C_SCL_STRETCH_DISABLE       (!SBC_EZI2C_SCL_STRETCH_ENABLE)
    #define SBC_EZI2C_SCL_STRETCH_ENABLE_CONST  (SBC_EZI2C_SCL_STRETCH_ENABLE)
    #define SBC_EZI2C_SCL_STRETCH_DISABLE_CONST (SBC_EZI2C_SCL_STRETCH_DISABLE)

    #define SBC_EZI2C_WAKE_ENABLE_CONST         (0u != SBC_EZI2C_WAKE_ENABLE)
    #define SBC_EZI2C_EC_AM_ENABLE              (0u != SBC_EZI2C_WAKE_ENABLE)

    #if (SBC_CY_SCBIP_V0 || SBC_CY_SCBIP_V1)
       #define SBC_EZI2C_FIFO_SIZE    (SBC_FIFO_SIZE)

    #else
        #define SBC_EZI2C_FIFO_SIZE \
                                            SBC_GET_FIFO_SIZE(SBC_EZI2C_BYTE_MODE_ENABLE)
    #endif /* (SBC_CY_SCBIP_V0 || SBC_CY_SCBIP_V1) */

#endif /* (SBC_SCB_MODE_UNCONFIG_CONST_CFG) */


/***************************************
*       Type Definitions
***************************************/

typedef struct
{
    uint32 enableClockStretch;
    uint32 enableMedianFilter;
    uint32 numberOfAddresses;
    uint32 primarySlaveAddr;
    uint32 secondarySlaveAddr;
    uint32 subAddrSize;
    uint32 enableWake;
    uint8  enableByteMode;
} SBC_EZI2C_INIT_STRUCT;


/***************************************
*        Function Prototypes
***************************************/

#if(SBC_SCB_MODE_UNCONFIG_CONST_CFG)
    void SBC_EzI2CInit(const SBC_EZI2C_INIT_STRUCT *config);
#endif /* (SBC_SCB_MODE_UNCONFIG_CONST_CFG) */

uint32 SBC_EzI2CGetActivity(void);

void   SBC_EzI2CSetAddress1(uint32 address);
uint32 SBC_EzI2CGetAddress1(void);
void   SBC_EzI2CSetBuffer1(uint32 bufSize, uint32 rwBoundary, volatile uint8 * buffer);
void   SBC_EzI2CSetReadBoundaryBuffer1(uint32 rwBoundary);

#if(SBC_SECONDARY_ADDRESS_ENABLE_CONST)
    void   SBC_EzI2CSetAddress2(uint32 address);
    uint32 SBC_EzI2CGetAddress2(void);
    void   SBC_EzI2CSetBuffer2(uint32 bufSize, uint32 rwBoundary, volatile uint8 * buffer);
    void   SBC_EzI2CSetReadBoundaryBuffer2(uint32 rwBoundary);
#endif /* (SBC_SECONDARY_ADDRESS_ENABLE_CONST) */

#if(SBC_EZI2C_SCL_STRETCH_ENABLE_CONST)
    CY_ISR_PROTO(SBC_EZI2C_STRETCH_ISR);
#endif /* (SBC_EZI2C_SCL_STRETCH_ENABLE_CONST) */

#if(SBC_EZI2C_SCL_STRETCH_DISABLE_CONST)
    CY_ISR_PROTO(SBC_EZI2C_NO_STRETCH_ISR);
#endif /* (SBC_EZI2C_SCL_STRETCH_DISABLE) */


/***************************************
*            API Constants
***************************************/

/* Configuration structure constants */
#define SBC_EZI2C_ONE_ADDRESS      (0u)
#define SBC_EZI2C_TWO_ADDRESSES    (1u)

#define SBC_EZI2C_PRIMARY_ADDRESS  (0u)
#define SBC_EZI2C_BOTH_ADDRESSES   (1u)

#define SBC_EZI2C_SUB_ADDR8_BITS   (0u)
#define SBC_EZI2C_SUB_ADDR16_BITS  (1u)

/* SBC_EzI2CGetActivity() return constants */
#define SBC_EZI2C_STATUS_SECOND_OFFSET (1u)
#define SBC_EZI2C_STATUS_READ1     ((uint32) (SBC_INTR_SLAVE_I2C_NACK))        /* Bit [1]   */
#define SBC_EZI2C_STATUS_WRITE1    ((uint32) (SBC_INTR_SLAVE_I2C_WRITE_STOP))  /* Bit [3]   */
#define SBC_EZI2C_STATUS_READ2     ((uint32) (SBC_INTR_SLAVE_I2C_NACK >> \
                                                           SBC_EZI2C_STATUS_SECOND_OFFSET)) /* Bit [0]   */
#define SBC_EZI2C_STATUS_WRITE2    ((uint32) (SBC_INTR_SLAVE_I2C_WRITE_STOP >> \
                                                           SBC_EZI2C_STATUS_SECOND_OFFSET)) /* Bit [2]   */
#define SBC_EZI2C_STATUS_ERR       ((uint32) (0x10u))                                       /* Bit [4]   */
#define SBC_EZI2C_STATUS_BUSY      ((uint32) (0x20u))                                       /* Bit [5]   */
#define SBC_EZI2C_CLEAR_STATUS     ((uint32) (0x1Fu))                                       /* Bits [0-4]*/
#define SBC_EZI2C_CMPLT_INTR_MASK  ((uint32) (SBC_INTR_SLAVE_I2C_NACK | \
                                                           SBC_INTR_SLAVE_I2C_WRITE_STOP))


/***************************************
*     Vars with External Linkage
***************************************/

#if(SBC_SCB_MODE_UNCONFIG_CONST_CFG)
    extern const SBC_EZI2C_INIT_STRUCT SBC_configEzI2C;
#endif /* (SBC_SCB_MODE_UNCONFIG_CONST_CFG) */


/***************************************
*           FSM states
***************************************/

/* Returns to master when there is no data to transmit */
#define SBC_EZI2C_OVFL_RETURN  (0xFFu)

/* States of EZI2C Slave FSM */
#define SBC_EZI2C_FSM_OFFSET_HI8 ((uint8) (0x02u)) /* Idle state for 1 addr: waits for high byte offset */
#define SBC_EZI2C_FSM_OFFSET_LO8 ((uint8) (0x00u)) /* Idle state for 2 addr: waits for low byte offset  */
#define SBC_EZI2C_FSM_BYTE_WRITE ((uint8) (0x01u)) /* Data byte write state: byte by byte mode          */
#define SBC_EZI2C_FSM_WAIT_STOP  ((uint8) (0x03u)) /* Discards written bytes as they do not match write
                                                                   criteria */
#define SBC_EZI2C_FSM_WRITE_MASK ((uint8) (0x01u)) /* Incorporates write states: EZI2C_FSM_BYTE_WRITE and
                                                                   EZI2C_FSM_WAIT_STOP  */

#define SBC_EZI2C_FSM_IDLE     ((SBC_SUB_ADDRESS_SIZE16) ?      \
                                                (SBC_EZI2C_FSM_OFFSET_HI8) : \
                                                (SBC_EZI2C_FSM_OFFSET_LO8))

#define SBC_EZI2C_CONTINUE_TRANSFER    (1u)
#define SBC_EZI2C_COMPLETE_TRANSFER    (0u)

#define SBC_EZI2C_NACK_RECEIVED_ADDRESS  (0u)
#define SBC_EZI2C_ACK_RECEIVED_ADDRESS   (1u)

#define SBC_EZI2C_ACTIVE_ADDRESS1  (0u)
#define SBC_EZI2C_ACTIVE_ADDRESS2  (1u)


/***************************************
*       Macro Definitions
***************************************/

/* Access to global variables */
#if(SBC_SECONDARY_ADDRESS_ENABLE_CONST)

    #define SBC_EZI2C_UPDATE_LOC_STATUS(activeAddress, locStatus) \
            do{ \
                (locStatus) >>= (activeAddress); \
            }while(0)

    #define SBC_EZI2C_GET_INDEX(activeAddress) \
            ((SBC_EZI2C_ACTIVE_ADDRESS1 == (activeAddress)) ? \
                ((uint32) SBC_indexBuf1) :                    \
                ((uint32) SBC_indexBuf2))

    #define SBC_EZI2C_GET_OFFSET(activeAddress) \
            ((SBC_EZI2C_ACTIVE_ADDRESS1 == (activeAddress)) ? \
                ((uint32) SBC_offsetBuf1) :                   \
                ((uint32) SBC_offsetBuf2))

    #define SBC_EZI2C_SET_INDEX(activeAddress, locIndex) \
            do{ \
                if(SBC_EZI2C_ACTIVE_ADDRESS1 == (activeAddress)) \
                {    \
                    SBC_indexBuf1 = (uint16) (locIndex); \
                }    \
                else \
                {    \
                    SBC_indexBuf2 = (uint16) (locIndex); \
                }    \
            }while(0)

    #define SBC_EZI2C_SET_OFFSET(activeAddress, locOffset) \
            do{ \
                if(SBC_EZI2C_ACTIVE_ADDRESS1 == (activeAddress)) \
                {    \
                    SBC_offsetBuf1 = (uint16) (locOffset); \
                }    \
                else \
                {    \
                    SBC_offsetBuf2 = (uint16) (locOffset); \
                }    \
            }while(0)
#else
    #define SBC_EZI2C_UPDATE_LOC_STATUS(activeAddress, locStatus)  do{ /* Empty*/ }while(0)

    #define SBC_EZI2C_GET_INDEX(activeAddress)  ((uint32) (SBC_indexBuf1))

    #define SBC_EZI2C_GET_OFFSET(activeAddress) ((uint32) (SBC_offsetBuf1))

    #define SBC_EZI2C_SET_INDEX(activeAddress, locIndex) \
            do{ \
                SBC_indexBuf1 = (uint16) (locIndex); \
            }while(0)

    #define SBC_EZI2C_SET_OFFSET(activeAddress, locOffset) \
            do{ \
                SBC_offsetBuf1 = (uint16) (locOffset); \
            }while(0)

#endif  /* (SBC_SUB_ADDRESS_SIZE16_CONST) */


/* This macro only applicable for EZI2C slave without clock stretching.
* It should not be used for other pusposes. */
#define SBC_EZI2C_TX_FIFO_CTRL_SET   (SBC_EZI2C_TX_FIFO_CTRL | \
                                                   SBC_TX_FIFO_CTRL_CLEAR)
#define SBC_EZI2C_TX_FIFO_CTRL_CLEAR (SBC_EZI2C_TX_FIFO_CTRL)
#define SBC_FAST_CLEAR_TX_FIFO \
                            do{             \
                                SBC_TX_FIFO_CTRL_REG = SBC_EZI2C_TX_FIFO_CTRL_SET;   \
                                SBC_TX_FIFO_CTRL_REG = SBC_EZI2C_TX_FIFO_CTRL_CLEAR; \
                            }while(0)


/***************************************
*      Common Register Settings
***************************************/

#define SBC_CTRL_EZI2C     (SBC_CTRL_MODE_I2C)

#define SBC_EZI2C_CTRL     (SBC_I2C_CTRL_S_GENERAL_IGNORE | \
                                         SBC_I2C_CTRL_SLAVE_MODE)

#define SBC_EZI2C_CTRL_AUTO    (SBC_I2C_CTRL_S_READY_ADDR_ACK      | \
                                             SBC_I2C_CTRL_S_READY_DATA_ACK      | \
                                             SBC_I2C_CTRL_S_NOT_READY_ADDR_NACK | \
                                             SBC_I2C_CTRL_S_NOT_READY_DATA_NACK)

#define SBC_EZI2C_RX_CTRL  ((SBC_FIFO_SIZE - 1u)   | \
                                          SBC_RX_CTRL_MSB_FIRST | \
                                          SBC_RX_CTRL_ENABLED)

#define SBC_EZI2C_TX_FIFO_CTRL (2u)
#define SBC_TX_LOAD_SIZE       (2u)

#define SBC_EZI2C_TX_CTRL  ((SBC_FIFO_SIZE - 1u)   | \
                                          SBC_TX_CTRL_MSB_FIRST | \
                                          SBC_TX_CTRL_ENABLED)

#define SBC_EZI2C_INTR_SLAVE_MASK  (SBC_INTR_SLAVE_I2C_BUS_ERROR | \
                                                 SBC_INTR_SLAVE_I2C_ARB_LOST  | \
                                                 SBC_INTR_SLAVE_I2C_STOP)

#define SBC_INTR_SLAVE_COMPLETE    (SBC_INTR_SLAVE_I2C_STOP | \
                                                 SBC_INTR_SLAVE_I2C_NACK | \
                                                 SBC_INTR_SLAVE_I2C_WRITE_STOP)


/***************************************
*    Initialization Register Settings
***************************************/

#if(SBC_SCB_MODE_EZI2C_CONST_CFG)

    #define SBC_EZI2C_DEFAULT_CTRL \
                                (SBC_GET_CTRL_BYTE_MODE  (SBC_EZI2C_BYTE_MODE_ENABLE)    | \
                                 SBC_GET_CTRL_ADDR_ACCEPT(SBC_EZI2C_NUMBER_OF_ADDRESSES) | \
                                 SBC_GET_CTRL_EC_AM_MODE (SBC_EZI2C_WAKE_ENABLE))

    #if(SBC_EZI2C_SCL_STRETCH_ENABLE_CONST)
        #define SBC_EZI2C_DEFAULT_I2C_CTRL (SBC_EZI2C_CTRL)
    #else
        #define SBC_EZI2C_DEFAULT_I2C_CTRL (SBC_EZI2C_CTRL_AUTO | SBC_EZI2C_CTRL)
    #endif /* (SBC_EZI2C_SCL_STRETCH_ENABLE_CONST) */


    #define SBC_EZI2C_DEFAULT_RX_MATCH \
                                (SBC_GET_I2C_8BIT_ADDRESS(SBC_EZI2C_PRIMARY_SLAVE_ADDRESS) | \
                                 SBC_GET_RX_MATCH_MASK   (SBC_EZI2C_SLAVE_ADDRESS_MASK))

    #define SBC_EZI2C_DEFAULT_RX_CTRL  (SBC_EZI2C_RX_CTRL)
    #define SBC_EZI2C_DEFAULT_TX_CTRL  (SBC_EZI2C_TX_CTRL)

    #define SBC_EZI2C_DEFAULT_RX_FIFO_CTRL (0u)
    #if(SBC_EZI2C_SCL_STRETCH_ENABLE_CONST)
        #define SBC_EZI2C_DEFAULT_TX_FIFO_CTRL (0u)
    #else
        #define SBC_EZI2C_DEFAULT_TX_FIFO_CTRL (2u)
    #endif /* (SBC_EZI2C_SCL_STRETCH_ENABLE_CONST) */

    /* Interrupt sources */
    #define SBC_EZI2C_DEFAULT_INTR_I2C_EC_MASK (SBC_NO_INTR_SOURCES)
    #define SBC_EZI2C_DEFAULT_INTR_SPI_EC_MASK (SBC_NO_INTR_SOURCES)
    #define SBC_EZI2C_DEFAULT_INTR_MASTER_MASK (SBC_NO_INTR_SOURCES)
    #define SBC_EZI2C_DEFAULT_INTR_TX_MASK     (SBC_NO_INTR_SOURCES)

    #if(SBC_EZI2C_SCL_STRETCH_ENABLE_CONST)
        #define SBC_EZI2C_DEFAULT_INTR_RX_MASK     (SBC_NO_INTR_SOURCES)
        #define SBC_EZI2C_DEFAULT_INTR_SLAVE_MASK  (SBC_INTR_SLAVE_I2C_ADDR_MATCH | \
                                                                 SBC_EZI2C_INTR_SLAVE_MASK)
    #else
        #define SBC_EZI2C_DEFAULT_INTR_RX_MASK     (SBC_INTR_RX_NOT_EMPTY)
        #define SBC_EZI2C_DEFAULT_INTR_SLAVE_MASK  (SBC_INTR_SLAVE_I2C_START | \
                                                                 SBC_EZI2C_INTR_SLAVE_MASK)
    #endif /* (SBC_EZI2C_SCL_STRETCH_ENABLE_CONST) */

#endif /* (SBC_SCB_MODE_EZI2C_CONST_CFG) */

#endif /* (CY_SCB_EZI2C_SBC_H) */


/* [] END OF FILE */
