/*******************************************************************************
* File Name: SBC_PINS.h
* Version 3.0
*
* Description:
*  This file provides constants and parameter values for the pin components
*  buried into SCB Component.
*
* Note:
*
********************************************************************************
* Copyright 2013-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_SCB_PINS_SBC_H)
#define CY_SCB_PINS_SBC_H

#include "cydevice_trm.h"
#include "cyfitter.h"
#include "cytypes.h"


/***************************************
*   Conditional Compilation Parameters
****************************************/

/* Unconfigured pins */
#define SBC_REMOVE_RX_WAKE_SDA_MOSI_PIN  (1u)
#define SBC_REMOVE_RX_SDA_MOSI_PIN      (1u)
#define SBC_REMOVE_TX_SCL_MISO_PIN      (1u)
#define SBC_REMOVE_CTS_SCLK_PIN      (1u)
#define SBC_REMOVE_RTS_SS0_PIN      (1u)
#define SBC_REMOVE_SS1_PIN                 (1u)
#define SBC_REMOVE_SS2_PIN                 (1u)
#define SBC_REMOVE_SS3_PIN                 (1u)

/* Mode defined pins */
#define SBC_REMOVE_I2C_PINS                (0u)
#define SBC_REMOVE_SPI_MASTER_PINS         (1u)
#define SBC_REMOVE_SPI_MASTER_SCLK_PIN     (1u)
#define SBC_REMOVE_SPI_MASTER_MOSI_PIN     (1u)
#define SBC_REMOVE_SPI_MASTER_MISO_PIN     (1u)
#define SBC_REMOVE_SPI_MASTER_SS0_PIN      (1u)
#define SBC_REMOVE_SPI_MASTER_SS1_PIN      (1u)
#define SBC_REMOVE_SPI_MASTER_SS2_PIN      (1u)
#define SBC_REMOVE_SPI_MASTER_SS3_PIN      (1u)
#define SBC_REMOVE_SPI_SLAVE_PINS          (1u)
#define SBC_REMOVE_SPI_SLAVE_MOSI_PIN      (1u)
#define SBC_REMOVE_SPI_SLAVE_MISO_PIN      (1u)
#define SBC_REMOVE_UART_TX_PIN             (1u)
#define SBC_REMOVE_UART_RX_TX_PIN          (1u)
#define SBC_REMOVE_UART_RX_PIN             (1u)
#define SBC_REMOVE_UART_RX_WAKE_PIN        (1u)
#define SBC_REMOVE_UART_RTS_PIN            (1u)
#define SBC_REMOVE_UART_CTS_PIN            (1u)

/* Unconfigured pins */
#define SBC_RX_WAKE_SDA_MOSI_PIN (0u == SBC_REMOVE_RX_WAKE_SDA_MOSI_PIN)
#define SBC_RX_SDA_MOSI_PIN     (0u == SBC_REMOVE_RX_SDA_MOSI_PIN)
#define SBC_TX_SCL_MISO_PIN     (0u == SBC_REMOVE_TX_SCL_MISO_PIN)
#define SBC_CTS_SCLK_PIN     (0u == SBC_REMOVE_CTS_SCLK_PIN)
#define SBC_RTS_SS0_PIN     (0u == SBC_REMOVE_RTS_SS0_PIN)
#define SBC_SS1_PIN                (0u == SBC_REMOVE_SS1_PIN)
#define SBC_SS2_PIN                (0u == SBC_REMOVE_SS2_PIN)
#define SBC_SS3_PIN                (0u == SBC_REMOVE_SS3_PIN)

/* Mode defined pins */
#define SBC_I2C_PINS               (0u == SBC_REMOVE_I2C_PINS)
#define SBC_SPI_MASTER_PINS        (0u == SBC_REMOVE_SPI_MASTER_PINS)
#define SBC_SPI_MASTER_SCLK_PIN    (0u == SBC_REMOVE_SPI_MASTER_SCLK_PIN)
#define SBC_SPI_MASTER_MOSI_PIN    (0u == SBC_REMOVE_SPI_MASTER_MOSI_PIN)
#define SBC_SPI_MASTER_MISO_PIN    (0u == SBC_REMOVE_SPI_MASTER_MISO_PIN)
#define SBC_SPI_MASTER_SS0_PIN     (0u == SBC_REMOVE_SPI_MASTER_SS0_PIN)
#define SBC_SPI_MASTER_SS1_PIN     (0u == SBC_REMOVE_SPI_MASTER_SS1_PIN)
#define SBC_SPI_MASTER_SS2_PIN     (0u == SBC_REMOVE_SPI_MASTER_SS2_PIN)
#define SBC_SPI_MASTER_SS3_PIN     (0u == SBC_REMOVE_SPI_MASTER_SS3_PIN)
#define SBC_SPI_SLAVE_PINS         (0u == SBC_REMOVE_SPI_SLAVE_PINS)
#define SBC_SPI_SLAVE_MOSI_PIN     (0u == SBC_REMOVE_SPI_SLAVE_MOSI_PIN)
#define SBC_SPI_SLAVE_MISO_PIN     (0u == SBC_REMOVE_SPI_SLAVE_MISO_PIN)
#define SBC_UART_TX_PIN            (0u == SBC_REMOVE_UART_TX_PIN)
#define SBC_UART_RX_TX_PIN         (0u == SBC_REMOVE_UART_RX_TX_PIN)
#define SBC_UART_RX_PIN            (0u == SBC_REMOVE_UART_RX_PIN)
#define SBC_UART_RX_WAKE_PIN       (0u == SBC_REMOVE_UART_RX_WAKE_PIN)
#define SBC_UART_RTS_PIN           (0u == SBC_REMOVE_UART_RTS_PIN)
#define SBC_UART_CTS_PIN           (0u == SBC_REMOVE_UART_CTS_PIN)


/***************************************
*             Includes
****************************************/

#if (SBC_RX_WAKE_SDA_MOSI_PIN)
    #include "SBC_uart_rx_wake_i2c_sda_spi_mosi.h"
#endif /* (SBC_RX_SDA_MOSI) */

#if (SBC_RX_SDA_MOSI_PIN)
    #include "SBC_uart_rx_i2c_sda_spi_mosi.h"
#endif /* (SBC_RX_SDA_MOSI) */

#if (SBC_TX_SCL_MISO_PIN)
    #include "SBC_uart_tx_i2c_scl_spi_miso.h"
#endif /* (SBC_TX_SCL_MISO) */

#if (SBC_CTS_SCLK_PIN)
    #include "SBC_uart_cts_spi_sclk.h"
#endif /* (SBC_CTS_SCLK) */

#if (SBC_RTS_SS0_PIN)
    #include "SBC_uart_rts_spi_ss0.h"
#endif /* (SBC_RTS_SS0_PIN) */

#if (SBC_SS1_PIN)
    #include "SBC_spi_ss1.h"
#endif /* (SBC_SS1_PIN) */

#if (SBC_SS2_PIN)
    #include "SBC_spi_ss2.h"
#endif /* (SBC_SS2_PIN) */

#if (SBC_SS3_PIN)
    #include "SBC_spi_ss3.h"
#endif /* (SBC_SS3_PIN) */

#if (SBC_I2C_PINS)
    #include "SBC_scl.h"
    #include "SBC_sda.h"
#endif /* (SBC_I2C_PINS) */

#if (SBC_SPI_MASTER_PINS)
#if (SBC_SPI_MASTER_SCLK_PIN)
    #include "SBC_sclk_m.h"
#endif /* (SBC_SPI_MASTER_SCLK_PIN) */

#if (SBC_SPI_MASTER_MOSI_PIN)
    #include "SBC_mosi_m.h"
#endif /* (SBC_SPI_MASTER_MOSI_PIN) */

#if (SBC_SPI_MASTER_MISO_PIN)
    #include "SBC_miso_m.h"
#endif /*(SBC_SPI_MASTER_MISO_PIN) */
#endif /* (SBC_SPI_MASTER_PINS) */

#if (SBC_SPI_SLAVE_PINS)
    #include "SBC_sclk_s.h"
    #include "SBC_ss_s.h"

#if (SBC_SPI_SLAVE_MOSI_PIN)
    #include "SBC_mosi_s.h"
#endif /* (SBC_SPI_SLAVE_MOSI_PIN) */

#if (SBC_SPI_SLAVE_MISO_PIN)
    #include "SBC_miso_s.h"
#endif /*(SBC_SPI_SLAVE_MISO_PIN) */
#endif /* (SBC_SPI_SLAVE_PINS) */

#if (SBC_SPI_MASTER_SS0_PIN)
    #include "SBC_ss0_m.h"
#endif /* (SBC_SPI_MASTER_SS0_PIN) */

#if (SBC_SPI_MASTER_SS1_PIN)
    #include "SBC_ss1_m.h"
#endif /* (SBC_SPI_MASTER_SS1_PIN) */

#if (SBC_SPI_MASTER_SS2_PIN)
    #include "SBC_ss2_m.h"
#endif /* (SBC_SPI_MASTER_SS2_PIN) */

#if (SBC_SPI_MASTER_SS3_PIN)
    #include "SBC_ss3_m.h"
#endif /* (SBC_SPI_MASTER_SS3_PIN) */

#if (SBC_UART_TX_PIN)
    #include "SBC_tx.h"
#endif /* (SBC_UART_TX_PIN) */

#if (SBC_UART_RX_TX_PIN)
    #include "SBC_rx_tx.h"
#endif /* (SBC_UART_RX_TX_PIN) */

#if (SBC_UART_RX_PIN)
    #include "SBC_rx.h"
#endif /* (SBC_UART_RX_PIN) */

#if (SBC_UART_RX_WAKE_PIN)
    #include "SBC_rx_wake.h"
#endif /* (SBC_UART_RX_WAKE_PIN) */

#if (SBC_UART_RTS_PIN)
    #include "SBC_rts.h"
#endif /* (SBC_UART_RTS_PIN) */

#if (SBC_UART_CTS_PIN)
    #include "SBC_cts.h"
#endif /* (SBC_UART_CTS_PIN) */


/***************************************
*              Registers
***************************************/

#if (SBC_RX_WAKE_SDA_MOSI_PIN)
    #define SBC_RX_WAKE_SDA_MOSI_HSIOM_REG \
                            (*(reg32 *) SBC_uart_rx_wake_i2c_sda_spi_mosi__0__HSIOM)
    #define SBC_RX_WAKE_SDA_MOSI_HSIOM_PTR \
                            ( (reg32 *) SBC_uart_rx_wake_i2c_sda_spi_mosi__0__HSIOM)
    #define SBC_RX_WAKE_SDA_MOSI_HSIOM_MASK \
                            (SBC_uart_rx_wake_i2c_sda_spi_mosi__0__HSIOM_MASK)
    #define SBC_RX_WAKE_SDA_MOSI_HSIOM_POS \
                            (SBC_uart_rx_wake_i2c_sda_spi_mosi__0__HSIOM_SHIFT)

    #define SBC_RX_WAKE_SDA_MOSI_INTCFG_REG \
                            (*(reg32 *) SBC_uart_rx_wake_i2c_sda_spi_mosi__0__INTCFG)
    #define SBC_RX_WAKE_SDA_MOSI_INTCFG_PTR \
                            ( (reg32 *) SBC_uart_rx_wake_i2c_sda_spi_mosi__0__INTCFG)
    #define SBC_RX_WAKE_SDA_MOSI_INTCFG_TYPE_POS  (SBC_uart_rx_wake_i2c_sda_spi_mosi__SHIFT)
    #define SBC_RX_WAKE_SDA_MOSI_INTCFG_TYPE_MASK \
                            ((uint32) SBC_INTCFG_TYPE_MASK << \
                                      SBC_RX_WAKE_SDA_MOSI_INTCFG_TYPE_POS)
#endif /* (SBC_RX_WAKE_SDA_MOSI_PIN) */

#if (SBC_RX_SDA_MOSI_PIN)
    #define SBC_RX_SDA_MOSI_HSIOM_REG   (*(reg32 *) SBC_uart_rx_i2c_sda_spi_mosi__0__HSIOM)
    #define SBC_RX_SDA_MOSI_HSIOM_PTR   ( (reg32 *) SBC_uart_rx_i2c_sda_spi_mosi__0__HSIOM)
    #define SBC_RX_SDA_MOSI_HSIOM_MASK  (SBC_uart_rx_i2c_sda_spi_mosi__0__HSIOM_MASK)
    #define SBC_RX_SDA_MOSI_HSIOM_POS   (SBC_uart_rx_i2c_sda_spi_mosi__0__HSIOM_SHIFT)
#endif /* (SBC_RX_SDA_MOSI_PIN) */

#if (SBC_TX_SCL_MISO_PIN)
    #define SBC_TX_SCL_MISO_HSIOM_REG   (*(reg32 *) SBC_uart_tx_i2c_scl_spi_miso__0__HSIOM)
    #define SBC_TX_SCL_MISO_HSIOM_PTR   ( (reg32 *) SBC_uart_tx_i2c_scl_spi_miso__0__HSIOM)
    #define SBC_TX_SCL_MISO_HSIOM_MASK  (SBC_uart_tx_i2c_scl_spi_miso__0__HSIOM_MASK)
    #define SBC_TX_SCL_MISO_HSIOM_POS   (SBC_uart_tx_i2c_scl_spi_miso__0__HSIOM_SHIFT)
#endif /* (SBC_TX_SCL_MISO_PIN) */

#if (SBC_CTS_SCLK_PIN)
    #define SBC_CTS_SCLK_HSIOM_REG   (*(reg32 *) SBC_uart_cts_spi_sclk__0__HSIOM)
    #define SBC_CTS_SCLK_HSIOM_PTR   ( (reg32 *) SBC_uart_cts_spi_sclk__0__HSIOM)
    #define SBC_CTS_SCLK_HSIOM_MASK  (SBC_uart_cts_spi_sclk__0__HSIOM_MASK)
    #define SBC_CTS_SCLK_HSIOM_POS   (SBC_uart_cts_spi_sclk__0__HSIOM_SHIFT)
#endif /* (SBC_CTS_SCLK_PIN) */

#if (SBC_RTS_SS0_PIN)
    #define SBC_RTS_SS0_HSIOM_REG   (*(reg32 *) SBC_uart_rts_spi_ss0__0__HSIOM)
    #define SBC_RTS_SS0_HSIOM_PTR   ( (reg32 *) SBC_uart_rts_spi_ss0__0__HSIOM)
    #define SBC_RTS_SS0_HSIOM_MASK  (SBC_uart_rts_spi_ss0__0__HSIOM_MASK)
    #define SBC_RTS_SS0_HSIOM_POS   (SBC_uart_rts_spi_ss0__0__HSIOM_SHIFT)
#endif /* (SBC_RTS_SS0_PIN) */

#if (SBC_SS1_PIN)
    #define SBC_SS1_HSIOM_REG      (*(reg32 *) SBC_spi_ss1__0__HSIOM)
    #define SBC_SS1_HSIOM_PTR      ( (reg32 *) SBC_spi_ss1__0__HSIOM)
    #define SBC_SS1_HSIOM_MASK     (SBC_spi_ss1__0__HSIOM_MASK)
    #define SBC_SS1_HSIOM_POS      (SBC_spi_ss1__0__HSIOM_SHIFT)
#endif /* (SBC_SS1_PIN) */

#if (SBC_SS2_PIN)
    #define SBC_SS2_HSIOM_REG     (*(reg32 *) SBC_spi_ss2__0__HSIOM)
    #define SBC_SS2_HSIOM_PTR     ( (reg32 *) SBC_spi_ss2__0__HSIOM)
    #define SBC_SS2_HSIOM_MASK    (SBC_spi_ss2__0__HSIOM_MASK)
    #define SBC_SS2_HSIOM_POS     (SBC_spi_ss2__0__HSIOM_SHIFT)
#endif /* (SBC_SS2_PIN) */

#if (SBC_SS3_PIN)
    #define SBC_SS3_HSIOM_REG     (*(reg32 *) SBC_spi_ss3__0__HSIOM)
    #define SBC_SS3_HSIOM_PTR     ( (reg32 *) SBC_spi_ss3__0__HSIOM)
    #define SBC_SS3_HSIOM_MASK    (SBC_spi_ss3__0__HSIOM_MASK)
    #define SBC_SS3_HSIOM_POS     (SBC_spi_ss3__0__HSIOM_SHIFT)
#endif /* (SBC_SS3_PIN) */

#if (SBC_I2C_PINS)
    #define SBC_SCL_HSIOM_REG     (*(reg32 *) SBC_scl__0__HSIOM)
    #define SBC_SCL_HSIOM_PTR     ( (reg32 *) SBC_scl__0__HSIOM)
    #define SBC_SCL_HSIOM_MASK    (SBC_scl__0__HSIOM_MASK)
    #define SBC_SCL_HSIOM_POS     (SBC_scl__0__HSIOM_SHIFT)

    #define SBC_SDA_HSIOM_REG     (*(reg32 *) SBC_sda__0__HSIOM)
    #define SBC_SDA_HSIOM_PTR     ( (reg32 *) SBC_sda__0__HSIOM)
    #define SBC_SDA_HSIOM_MASK    (SBC_sda__0__HSIOM_MASK)
    #define SBC_SDA_HSIOM_POS     (SBC_sda__0__HSIOM_SHIFT)
#endif /* (SBC_I2C_PINS) */

#if (SBC_SPI_MASTER_SCLK_PIN)
    #define SBC_SCLK_M_HSIOM_REG   (*(reg32 *) SBC_sclk_m__0__HSIOM)
    #define SBC_SCLK_M_HSIOM_PTR   ( (reg32 *) SBC_sclk_m__0__HSIOM)
    #define SBC_SCLK_M_HSIOM_MASK  (SBC_sclk_m__0__HSIOM_MASK)
    #define SBC_SCLK_M_HSIOM_POS   (SBC_sclk_m__0__HSIOM_SHIFT)
#endif /* (SBC_SPI_MASTER_SCLK_PIN) */

#if (SBC_SPI_MASTER_SS0_PIN)
    #define SBC_SS0_M_HSIOM_REG    (*(reg32 *) SBC_ss0_m__0__HSIOM)
    #define SBC_SS0_M_HSIOM_PTR    ( (reg32 *) SBC_ss0_m__0__HSIOM)
    #define SBC_SS0_M_HSIOM_MASK   (SBC_ss0_m__0__HSIOM_MASK)
    #define SBC_SS0_M_HSIOM_POS    (SBC_ss0_m__0__HSIOM_SHIFT)
#endif /* (SBC_SPI_MASTER_SS0_PIN) */

#if (SBC_SPI_MASTER_SS1_PIN)
    #define SBC_SS1_M_HSIOM_REG    (*(reg32 *) SBC_ss1_m__0__HSIOM)
    #define SBC_SS1_M_HSIOM_PTR    ( (reg32 *) SBC_ss1_m__0__HSIOM)
    #define SBC_SS1_M_HSIOM_MASK   (SBC_ss1_m__0__HSIOM_MASK)
    #define SBC_SS1_M_HSIOM_POS    (SBC_ss1_m__0__HSIOM_SHIFT)
#endif /* (SBC_SPI_MASTER_SS1_PIN) */

#if (SBC_SPI_MASTER_SS2_PIN)
    #define SBC_SS2_M_HSIOM_REG    (*(reg32 *) SBC_ss2_m__0__HSIOM)
    #define SBC_SS2_M_HSIOM_PTR    ( (reg32 *) SBC_ss2_m__0__HSIOM)
    #define SBC_SS2_M_HSIOM_MASK   (SBC_ss2_m__0__HSIOM_MASK)
    #define SBC_SS2_M_HSIOM_POS    (SBC_ss2_m__0__HSIOM_SHIFT)
#endif /* (SBC_SPI_MASTER_SS2_PIN) */

#if (SBC_SPI_MASTER_SS3_PIN)
    #define SBC_SS3_M_HSIOM_REG    (*(reg32 *) SBC_ss3_m__0__HSIOM)
    #define SBC_SS3_M_HSIOM_PTR    ( (reg32 *) SBC_ss3_m__0__HSIOM)
    #define SBC_SS3_M_HSIOM_MASK   (SBC_ss3_m__0__HSIOM_MASK)
    #define SBC_SS3_M_HSIOM_POS    (SBC_ss3_m__0__HSIOM_SHIFT)
#endif /* (SBC_SPI_MASTER_SS3_PIN) */

#if (SBC_UART_TX_PIN)
    #define SBC_TX_HSIOM_REG   (*(reg32 *) SBC_tx__0__HSIOM)
    #define SBC_TX_HSIOM_PTR   ( (reg32 *) SBC_tx_0__HSIOM)
    #define SBC_TX_HSIOM_MASK  (SBC_tx__0__HSIOM_MASK)
    #define SBC_TX_HSIOM_POS   (SBC_tx__0__HSIOM_SHIFT)
#endif /* (SBC_UART_TX_PIN) */

#if (SBC_UART_RTS_PIN)
    #define SBC_RTS_HSIOM_REG  (*(reg32 *) SBC_rts__0__HSIOM)
    #define SBC_RTS_HSIOM_PTR  ( (reg32 *) SBC_rts__0__HSIOM)
    #define SBC_RTS_HSIOM_MASK (SBC_rts__0__HSIOM_MASK)
    #define SBC_RTS_HSIOM_POS  (SBC_rts__0__HSIOM_SHIFT)
#endif /* (SBC_UART_RTS_PIN) */


/***************************************
*        Registers Constants
***************************************/

/* Pins constants */
#define SBC_HSIOM_DEF_SEL      (0x00u)
#define SBC_HSIOM_GPIO_SEL     (0x00u)
#define SBC_HSIOM_UART_SEL     (0x09u)
#define SBC_HSIOM_I2C_SEL      (0x0Eu)
#define SBC_HSIOM_SPI_SEL      (0x0Fu)

#define SBC_RX_WAKE_SDA_MOSI_PIN_INDEX   (0u)
#define SBC_RX_SDA_MOSI_PIN_INDEX       (0u)
#define SBC_TX_SCL_MISO_PIN_INDEX       (1u)
#define SBC_CTS_SCLK_PIN_INDEX       (2u)
#define SBC_RTS_SS0_PIN_INDEX       (3u)
#define SBC_SS1_PIN_INDEX                  (4u)
#define SBC_SS2_PIN_INDEX                  (5u)
#define SBC_SS3_PIN_INDEX                  (6u)

#define SBC_RX_WAKE_SDA_MOSI_PIN_MASK ((uint32) 0x01u << SBC_RX_WAKE_SDA_MOSI_PIN_INDEX)
#define SBC_RX_SDA_MOSI_PIN_MASK     ((uint32) 0x01u << SBC_RX_SDA_MOSI_PIN_INDEX)
#define SBC_TX_SCL_MISO_PIN_MASK     ((uint32) 0x01u << SBC_TX_SCL_MISO_PIN_INDEX)
#define SBC_CTS_SCLK_PIN_MASK     ((uint32) 0x01u << SBC_CTS_SCLK_PIN_INDEX)
#define SBC_RTS_SS0_PIN_MASK     ((uint32) 0x01u << SBC_RTS_SS0_PIN_INDEX)
#define SBC_SS1_PIN_MASK                ((uint32) 0x01u << SBC_SS1_PIN_INDEX)
#define SBC_SS2_PIN_MASK                ((uint32) 0x01u << SBC_SS2_PIN_INDEX)
#define SBC_SS3_PIN_MASK                ((uint32) 0x01u << SBC_SS3_PIN_INDEX)

/* Pin interrupt constants */
#define SBC_INTCFG_TYPE_MASK           (0x03u)
#define SBC_INTCFG_TYPE_FALLING_EDGE   (0x02u)

/* Pin Drive Mode constants */
#define SBC_PIN_DM_ALG_HIZ  (0u)
#define SBC_PIN_DM_DIG_HIZ  (1u)
#define SBC_PIN_DM_OD_LO    (4u)
#define SBC_PIN_DM_STRONG   (6u)


/***************************************
*          Macro Definitions
***************************************/

/* Return drive mode of the pin */
#define SBC_DM_MASK    (0x7u)
#define SBC_DM_SIZE    (3)
#define SBC_GET_P4_PIN_DM(reg, pos) \
    ( ((reg) & (uint32) ((uint32) SBC_DM_MASK << (SBC_DM_SIZE * (pos)))) >> \
                                                              (SBC_DM_SIZE * (pos)) )

#if (SBC_TX_SCL_MISO_PIN)
    #define SBC_CHECK_TX_SCL_MISO_PIN_USED \
                (SBC_PIN_DM_ALG_HIZ != \
                    SBC_GET_P4_PIN_DM(SBC_uart_tx_i2c_scl_spi_miso_PC, \
                                                   SBC_uart_tx_i2c_scl_spi_miso_SHIFT))
#endif /* (SBC_TX_SCL_MISO_PIN) */

#if (SBC_RTS_SS0_PIN)
    #define SBC_CHECK_RTS_SS0_PIN_USED \
                (SBC_PIN_DM_ALG_HIZ != \
                    SBC_GET_P4_PIN_DM(SBC_uart_rts_spi_ss0_PC, \
                                                   SBC_uart_rts_spi_ss0_SHIFT))
#endif /* (SBC_RTS_SS0_PIN) */

/* Set bits-mask in register */
#define SBC_SET_REGISTER_BITS(reg, mask, pos, mode) \
                    do                                           \
                    {                                            \
                        (reg) = (((reg) & ((uint32) ~(uint32) (mask))) | ((uint32) ((uint32) (mode) << (pos)))); \
                    }while(0)

/* Set bit in the register */
#define SBC_SET_REGISTER_BIT(reg, mask, val) \
                    ((val) ? ((reg) |= (mask)) : ((reg) &= ((uint32) ~((uint32) (mask)))))

#define SBC_SET_HSIOM_SEL(reg, mask, pos, sel) SBC_SET_REGISTER_BITS(reg, mask, pos, sel)
#define SBC_SET_INCFG_TYPE(reg, mask, pos, intType) \
                                                        SBC_SET_REGISTER_BITS(reg, mask, pos, intType)
#define SBC_SET_INP_DIS(reg, mask, val) SBC_SET_REGISTER_BIT(reg, mask, val)

/* SBC_SET_I2C_SCL_DR(val) - Sets I2C SCL DR register.
*  SBC_SET_I2C_SCL_HSIOM_SEL(sel) - Sets I2C SCL HSIOM settings.
*/
/* SCB I2C: scl signal */
#if (SBC_CY_SCBIP_V0)
#if (SBC_I2C_PINS)
    #define SBC_SET_I2C_SCL_DR(val) SBC_scl_Write(val)

    #define SBC_SET_I2C_SCL_HSIOM_SEL(sel) \
                          SBC_SET_HSIOM_SEL(SBC_SCL_HSIOM_REG,  \
                                                         SBC_SCL_HSIOM_MASK, \
                                                         SBC_SCL_HSIOM_POS,  \
                                                         (sel))
    #define SBC_WAIT_SCL_SET_HIGH  (0u == SBC_scl_Read())

/* Unconfigured SCB: scl signal */
#elif (SBC_RX_WAKE_SDA_MOSI_PIN)
    #define SBC_SET_I2C_SCL_DR(val) \
                            SBC_uart_rx_wake_i2c_sda_spi_mosi_Write(val)

    #define SBC_SET_I2C_SCL_HSIOM_SEL(sel) \
                    SBC_SET_HSIOM_SEL(SBC_RX_WAKE_SDA_MOSI_HSIOM_REG,  \
                                                   SBC_RX_WAKE_SDA_MOSI_HSIOM_MASK, \
                                                   SBC_RX_WAKE_SDA_MOSI_HSIOM_POS,  \
                                                   (sel))

    #define SBC_WAIT_SCL_SET_HIGH  (0u == SBC_uart_rx_wake_i2c_sda_spi_mosi_Read())

#elif (SBC_RX_SDA_MOSI_PIN)
    #define SBC_SET_I2C_SCL_DR(val) \
                            SBC_uart_rx_i2c_sda_spi_mosi_Write(val)


    #define SBC_SET_I2C_SCL_HSIOM_SEL(sel) \
                            SBC_SET_HSIOM_SEL(SBC_RX_SDA_MOSI_HSIOM_REG,  \
                                                           SBC_RX_SDA_MOSI_HSIOM_MASK, \
                                                           SBC_RX_SDA_MOSI_HSIOM_POS,  \
                                                           (sel))

    #define SBC_WAIT_SCL_SET_HIGH  (0u == SBC_uart_rx_i2c_sda_spi_mosi_Read())

#else
    #define SBC_SET_I2C_SCL_DR(val) \
                                                    do{ /* Does nothing */ }while(0)
    #define SBC_SET_I2C_SCL_HSIOM_SEL(sel) \
                                                    do{ /* Does nothing */ }while(0)

    #define SBC_WAIT_SCL_SET_HIGH  (0u)
#endif /* (SBC_I2C_PINS) */

/* SCB I2C: sda signal */
#if (SBC_I2C_PINS)
    #define SBC_WAIT_SDA_SET_HIGH  (0u == SBC_sda_Read())
/* Unconfigured SCB: sda signal */
#elif (SBC_TX_SCL_MISO_PIN)
    #define SBC_WAIT_SDA_SET_HIGH  (0u == SBC_uart_tx_i2c_scl_spi_miso_Read())
#else
    #define SBC_WAIT_SDA_SET_HIGH  (0u)
#endif /* (SBC_MOSI_SCL_RX_PIN) */
#endif /* (SBC_CY_SCBIP_V0) */


/***************************************
* The following code is DEPRECATED and
* must not be used.
***************************************/

/* Unconfigured pins */
#define SBC_REMOVE_MOSI_SCL_RX_WAKE_PIN    SBC_REMOVE_RX_WAKE_SDA_MOSI_PIN
#define SBC_REMOVE_MOSI_SCL_RX_PIN         SBC_REMOVE_RX_SDA_MOSI_PIN
#define SBC_REMOVE_MISO_SDA_TX_PIN         SBC_REMOVE_TX_SCL_MISO_PIN
#ifndef SBC_REMOVE_SCLK_PIN
#define SBC_REMOVE_SCLK_PIN                SBC_REMOVE_CTS_SCLK_PIN
#endif /* SBC_REMOVE_SCLK_PIN */
#ifndef SBC_REMOVE_SS0_PIN
#define SBC_REMOVE_SS0_PIN                 SBC_REMOVE_RTS_SS0_PIN
#endif /* SBC_REMOVE_SS0_PIN */

/* Unconfigured pins */
#define SBC_MOSI_SCL_RX_WAKE_PIN   SBC_RX_WAKE_SDA_MOSI_PIN
#define SBC_MOSI_SCL_RX_PIN        SBC_RX_SDA_MOSI_PIN
#define SBC_MISO_SDA_TX_PIN        SBC_TX_SCL_MISO_PIN
#ifndef SBC_SCLK_PIN
#define SBC_SCLK_PIN               SBC_CTS_SCLK_PIN
#endif /* SBC_SCLK_PIN */
#ifndef SBC_SS0_PIN
#define SBC_SS0_PIN                SBC_RTS_SS0_PIN
#endif /* SBC_SS0_PIN */

#if (SBC_MOSI_SCL_RX_WAKE_PIN)
    #define SBC_MOSI_SCL_RX_WAKE_HSIOM_REG     SBC_RX_WAKE_SDA_MOSI_HSIOM_REG
    #define SBC_MOSI_SCL_RX_WAKE_HSIOM_PTR     SBC_RX_WAKE_SDA_MOSI_HSIOM_REG
    #define SBC_MOSI_SCL_RX_WAKE_HSIOM_MASK    SBC_RX_WAKE_SDA_MOSI_HSIOM_REG
    #define SBC_MOSI_SCL_RX_WAKE_HSIOM_POS     SBC_RX_WAKE_SDA_MOSI_HSIOM_REG

    #define SBC_MOSI_SCL_RX_WAKE_INTCFG_REG    SBC_RX_WAKE_SDA_MOSI_HSIOM_REG
    #define SBC_MOSI_SCL_RX_WAKE_INTCFG_PTR    SBC_RX_WAKE_SDA_MOSI_HSIOM_REG

    #define SBC_MOSI_SCL_RX_WAKE_INTCFG_TYPE_POS   SBC_RX_WAKE_SDA_MOSI_HSIOM_REG
    #define SBC_MOSI_SCL_RX_WAKE_INTCFG_TYPE_MASK  SBC_RX_WAKE_SDA_MOSI_HSIOM_REG
#endif /* (SBC_RX_WAKE_SDA_MOSI_PIN) */

#if (SBC_MOSI_SCL_RX_PIN)
    #define SBC_MOSI_SCL_RX_HSIOM_REG      SBC_RX_SDA_MOSI_HSIOM_REG
    #define SBC_MOSI_SCL_RX_HSIOM_PTR      SBC_RX_SDA_MOSI_HSIOM_PTR
    #define SBC_MOSI_SCL_RX_HSIOM_MASK     SBC_RX_SDA_MOSI_HSIOM_MASK
    #define SBC_MOSI_SCL_RX_HSIOM_POS      SBC_RX_SDA_MOSI_HSIOM_POS
#endif /* (SBC_MOSI_SCL_RX_PIN) */

#if (SBC_MISO_SDA_TX_PIN)
    #define SBC_MISO_SDA_TX_HSIOM_REG      SBC_TX_SCL_MISO_HSIOM_REG
    #define SBC_MISO_SDA_TX_HSIOM_PTR      SBC_TX_SCL_MISO_HSIOM_REG
    #define SBC_MISO_SDA_TX_HSIOM_MASK     SBC_TX_SCL_MISO_HSIOM_REG
    #define SBC_MISO_SDA_TX_HSIOM_POS      SBC_TX_SCL_MISO_HSIOM_REG
#endif /* (SBC_MISO_SDA_TX_PIN_PIN) */

#if (SBC_SCLK_PIN)
    #ifndef SBC_SCLK_HSIOM_REG
    #define SBC_SCLK_HSIOM_REG     SBC_CTS_SCLK_HSIOM_REG
    #define SBC_SCLK_HSIOM_PTR     SBC_CTS_SCLK_HSIOM_PTR
    #define SBC_SCLK_HSIOM_MASK    SBC_CTS_SCLK_HSIOM_MASK
    #define SBC_SCLK_HSIOM_POS     SBC_CTS_SCLK_HSIOM_POS
    #endif /* SBC_SCLK_HSIOM_REG */
#endif /* (SBC_SCLK_PIN) */

#if (SBC_SS0_PIN)
    #ifndef SBC_SS0_HSIOM_REG
    #define SBC_SS0_HSIOM_REG      SBC_RTS_SS0_HSIOM_REG
    #define SBC_SS0_HSIOM_PTR      SBC_RTS_SS0_HSIOM_PTR
    #define SBC_SS0_HSIOM_MASK     SBC_RTS_SS0_HSIOM_MASK
    #define SBC_SS0_HSIOM_POS      SBC_RTS_SS0_HSIOM_POS
    #endif /* SBC_SS0_HSIOM_REG */
#endif /* (SBC_SS0_PIN) */

#define SBC_MOSI_SCL_RX_WAKE_PIN_INDEX SBC_RX_WAKE_SDA_MOSI_PIN_INDEX
#define SBC_MOSI_SCL_RX_PIN_INDEX      SBC_RX_SDA_MOSI_PIN_INDEX
#define SBC_MISO_SDA_TX_PIN_INDEX      SBC_TX_SCL_MISO_PIN_INDEX
#ifndef SBC_SCLK_PIN_INDEX
#define SBC_SCLK_PIN_INDEX             SBC_CTS_SCLK_PIN_INDEX
#endif /* SBC_SCLK_PIN_INDEX */
#ifndef SBC_SS0_PIN_INDEX
#define SBC_SS0_PIN_INDEX              SBC_RTS_SS0_PIN_INDEX
#endif /* SBC_SS0_PIN_INDEX */

#define SBC_MOSI_SCL_RX_WAKE_PIN_MASK SBC_RX_WAKE_SDA_MOSI_PIN_MASK
#define SBC_MOSI_SCL_RX_PIN_MASK      SBC_RX_SDA_MOSI_PIN_MASK
#define SBC_MISO_SDA_TX_PIN_MASK      SBC_TX_SCL_MISO_PIN_MASK
#ifndef SBC_SCLK_PIN_MASK
#define SBC_SCLK_PIN_MASK             SBC_CTS_SCLK_PIN_MASK
#endif /* SBC_SCLK_PIN_MASK */
#ifndef SBC_SS0_PIN_MASK
#define SBC_SS0_PIN_MASK              SBC_RTS_SS0_PIN_MASK
#endif /* SBC_SS0_PIN_MASK */

#endif /* (CY_SCB_PINS_SBC_H) */


/* [] END OF FILE */
