/*******************************************************************************
* File Name: .h
* Version 3.0
*
* Description:
*  This private file provides constants and parameter values for the
*  SCB Component.
*  Please do not use this file or its content in your project.
*
* Note:
*
********************************************************************************
* Copyright 2013-2015, Cypress Semiconductor Corporation. All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_SCB_PVT_SBC_H)
#define CY_SCB_PVT_SBC_H

#include "SBC.h"


/***************************************
*     Private Function Prototypes
***************************************/

/* APIs to service INTR_I2C_EC register */
#define SBC_SetI2CExtClkInterruptMode(interruptMask) SBC_WRITE_INTR_I2C_EC_MASK(interruptMask)
#define SBC_ClearI2CExtClkInterruptSource(interruptMask) SBC_CLEAR_INTR_I2C_EC(interruptMask)
#define SBC_GetI2CExtClkInterruptSource()                (SBC_INTR_I2C_EC_REG)
#define SBC_GetI2CExtClkInterruptMode()                  (SBC_INTR_I2C_EC_MASK_REG)
#define SBC_GetI2CExtClkInterruptSourceMasked()          (SBC_INTR_I2C_EC_MASKED_REG)

#if (!SBC_CY_SCBIP_V1)
    /* APIs to service INTR_SPI_EC register */
    #define SBC_SetSpiExtClkInterruptMode(interruptMask) \
                                                                SBC_WRITE_INTR_SPI_EC_MASK(interruptMask)
    #define SBC_ClearSpiExtClkInterruptSource(interruptMask) \
                                                                SBC_CLEAR_INTR_SPI_EC(interruptMask)
    #define SBC_GetExtSpiClkInterruptSource()                 (SBC_INTR_SPI_EC_REG)
    #define SBC_GetExtSpiClkInterruptMode()                   (SBC_INTR_SPI_EC_MASK_REG)
    #define SBC_GetExtSpiClkInterruptSourceMasked()           (SBC_INTR_SPI_EC_MASKED_REG)
#endif /* (!SBC_CY_SCBIP_V1) */

#if(SBC_SCB_MODE_UNCONFIG_CONST_CFG)
    extern void SBC_SetPins(uint32 mode, uint32 subMode, uint32 uartEnableMask);
#endif /* (SBC_SCB_MODE_UNCONFIG_CONST_CFG) */


/***************************************
*     Vars with External Linkage
***************************************/

#if (SBC_SCB_IRQ_INTERNAL)
#if !defined (CY_REMOVE_SBC_CUSTOM_INTR_HANDLER)
    extern cyisraddress SBC_customIntrHandler;
#endif /* !defined (CY_REMOVE_SBC_CUSTOM_INTR_HANDLER) */
#endif /* (SBC_SCB_IRQ_INTERNAL) */

extern SBC_BACKUP_STRUCT SBC_backup;

#if(SBC_SCB_MODE_UNCONFIG_CONST_CFG)
    /* Common configuration variables */
    extern uint8 SBC_scbMode;
    extern uint8 SBC_scbEnableWake;
    extern uint8 SBC_scbEnableIntr;

    /* I2C configuration variables */
    extern uint8 SBC_mode;
    extern uint8 SBC_acceptAddr;

    /* SPI/UART configuration variables */
    extern volatile uint8 * SBC_rxBuffer;
    extern uint8   SBC_rxDataBits;
    extern uint32  SBC_rxBufferSize;

    extern volatile uint8 * SBC_txBuffer;
    extern uint8   SBC_txDataBits;
    extern uint32  SBC_txBufferSize;

    /* EZI2C configuration variables */
    extern uint8 SBC_numberOfAddr;
    extern uint8 SBC_subAddrSize;
#endif /* (SBC_SCB_MODE_UNCONFIG_CONST_CFG) */


/***************************************
*        Conditional Macro
****************************************/

#if(SBC_SCB_MODE_UNCONFIG_CONST_CFG)
    /* Defines run time operation mode */
    #define SBC_SCB_MODE_I2C_RUNTM_CFG     (SBC_SCB_MODE_I2C      == SBC_scbMode)
    #define SBC_SCB_MODE_SPI_RUNTM_CFG     (SBC_SCB_MODE_SPI      == SBC_scbMode)
    #define SBC_SCB_MODE_UART_RUNTM_CFG    (SBC_SCB_MODE_UART     == SBC_scbMode)
    #define SBC_SCB_MODE_EZI2C_RUNTM_CFG   (SBC_SCB_MODE_EZI2C    == SBC_scbMode)
    #define SBC_SCB_MODE_UNCONFIG_RUNTM_CFG \
                                                        (SBC_SCB_MODE_UNCONFIG == SBC_scbMode)

    /* Defines wakeup enable */
    #define SBC_SCB_WAKE_ENABLE_CHECK       (0u != SBC_scbEnableWake)
#endif /* (SBC_SCB_MODE_UNCONFIG_CONST_CFG) */

/* Defines maximum number of SCB pins */
#if (!SBC_CY_SCBIP_V1)
    #define SBC_SCB_PINS_NUMBER    (7u)
#else
    #define SBC_SCB_PINS_NUMBER    (2u)
#endif /* (!SBC_CY_SCBIP_V1) */

#endif /* (CY_SCB_PVT_SBC_H) */


/* [] END OF FILE */
